---
title: "Welcome"
start: true
teaching: 15
exercises: 15
questions:
- "What is The Carpentries and how do we approach teaching?"
- "What should you expect from this workshop?"
objectives:
- "Identify common ground with some of your fellow workshop participants."
- "Understand a general structure and core goals of The Carpentries."
- "Predict what will and will not be covered in this workshop."
- "Know where to find The Carpentries Code of Conduct and how to report an incident."
keypoints:
- "The Carpentries is a community of practice. We strive to provide a welcoming environment for all learners and take our Code of Conduct seriously."
- "This episode sets the stage for the entire workshop. The introductions and exercises help everyone begin to develop a relationship and trust."
- "This workshop will cover evidence-based teaching practices and how they apply specifically to The Carpentries."
- "Learner motivation and prior knowledge vary widely, and can be quickly assessed with a multiple choice question."
---

> ## Pronouns and Names
>
> Using correct names and pronouns (e.g. "she/her") is important for setting a respectful tone. Learning these is hard to
> do quickly, so we recommend displaying it prominently during the workshop.
>
> In an online workshop, give everyone a moment to update their display name to reflect how they would like to be addressed.
>
> At an in-person event, we recommend supplying name tags and markers, or using plain paper to create table-displayed name placards.
>
> Note that pronouns are personal and some participants might prefer not to share them.
> Do not force people to share their pronouns.
> One reason to avoid pressuring people to share them is to allow people to share their 
> gender identity only when they feel ready to. 
> It is, however, necessary for all participants to use pronouns and names as listed when participants provide them. 
> 
> For those unfamiliar with the practice of sharing pronouns, these resources may be helpful 
> for further reading: 
> 
> * The proper use of pronouns in language: https://lgbt.ucsf.edu/pronounsmatter
> * The importance of using pronouns: https://www.pronouns.org/
> * How to use personal pronouns: https://www.pronouns.org/how
> * How to deal with situations when you use the wrong pronoun: https://www.pronouns.org/mistakes
> 
{: .discussion}


![Photo of an Icebreaker ship, named Stephan Jantzen](../fig/Icebreaker_Stephan_Jantzen_in_Stadthafen_Rostock_2010-12-28_perspective_correction-GD.jpg){: width="600px" }  
A different kind of "icebreaker." Photo credit: Grand-Duc, Wikipedia, http://en.wikipedia.org/wiki/User:Grand-Duc

## Before The Course Begins

> ## Getting to know each other
>
> If the Trainer has chosen an [icebreaker question]({{ site.training_site }}/icebreakers/index.html),
> participate by writing your answers in the Etherpad.
{: .challenge}


## Code of Conduct

To make clear what is expected, everyone participating in The Carpentries activities is required
to abide by our [Code of Conduct][coc]. Any form of behaviour to exclude, intimidate,
or cause discomfort is a violation of the Code of Conduct. In order to foster a positive and professional
learning environment we encourage you to:  
* Use welcoming and inclusive language
* Be respectful of different viewpoints and experiences
* Gracefully accept constructive criticism
* Focus on what is best for the community
* Show courtesy and respect towards other community members

If you believe someone is violating the Code of Conduct, we ask that you report it to The Carpentries
Code of Conduct Committee by completing [this form](https://goo.gl/forms/KoUfO53Za3apOuOK2).

## Introductions
Hello everyone, and welcome to The Carpentries
instructor training.  We are very pleased to have you with us.

> ## This Event's Trainers
>
> To begin class, each Trainer should give a brief introduction of themselves.
>
> (For some guidelines on introducing yourself, see some content from
> later in the workshop: [Workshop Introductions](https://carpentries.github.io/instructor-training/23-introductions/index.html))
{: .discussion}

Now, we would like to get to know all of you.

> ## Reviewing The Carpentries Experience and Goals
>
> For the multiple choice questions below, please place an "X" next to the response(s) that best apply to you. Then find yourself a spot
> in the Etherpad below to write a short response to the last question.
>
> *Have you ever participated in a Software Carpentry, Data Carpentry, or Library Carpentry Workshop?*
>
> 1.  Yes, I have taken a workshop.
> 2.  Yes, I have been a workshop helper.
> 3.  Yes, I organized a workshop.
> 4.  No, but I am familiar with what is taught at a workshop.
> 5.  No, and I am not familiar with what is taught at a workshop.
>
> *Which of these most accurately describes your teaching experience?*
>
> 1.  I have been a graduate or undergraduate teaching assistant for a university/college course.
> 2.  I have not had any teaching experience in the past.
> 3.  I have taught a seminar, workshop, or other short or informal course.
> 4.  I have been the primary or responsible teacher for a university/college course.
> 5.  I have taught at the primary or secondary education level.
> 6.  I have taught informally through outreach programs, hackathons, libraries, laboratory demonstrations, and similar activities.
>
> **Why are you taking this course? What goals do you have for this training?**
>
> This exercise should take about 5 minutes for responses, with an optional 10 for additional discussion as time permits.
{: .challenge}

To make sure everyone has the
same context, we will give a brief overview of The Carpentries
organization before starting the training.

## A Brief Overview of The Carpentries

![Image of action figures in a workshop with Instructor, Co-Instructor, Helper, and Sticky Notes labeled](../fig/Scene_1_blue_stickies_labeled.jpeg){: width="900px" }

Software Carpentry, Data Carpentry, and Library Carpentry
are official Lesson Programs of The Carpentries.
The Carpentries is a **global community of volunteer researchers, educators, and others** oriented around
improving basic computing and data skills for
researchers through intensive, short-format workshops.
* Software Carpentry focuses on helping researchers develop foundational
computational skills
* Data Carpentry focuses on helping
researchers work effectively with their data through its lifecycle
* Library Carpentry focuses on teaching data skills to people working in library- and information-related roles.

The main goal of The Carpentries is not to teach specific skills, per se - although those
are covered - but rather, to convey best practices that will enable
researchers to be more productive and do better research.

## Instructor Training Workshop Overview

The goal of this training is to provide you with the skills and information you need
to become a certified Carpentries Instructor. Our expectations of certified
Instructors is that they:

- be familiar with and understand **how to apply research-based teaching principles**,
especially as they apply to The Carpentries audience.
- understand the **importance of a respectful and inclusive classroom environment**; commit to
creating such an environment; and be able to
identify and implement The Carpentries policies and general practices to accomplish this.
- **practice and develop skills** in the teaching methods used in The Carpentries workshops.
- learn enough about The Carpentries organisation to **know where to go for help**,
how to start organizing a workshop, and how to get involved with community activities.

These four goals are broken down into four main themes of content:

### How Learning Works

One of our main emphases will be discussing the "best practices" of teaching. We
will be introducing you to a handful of key educational research
findings and demonstrating how they can be used to help people learn better and faster.

### Building Teaching Skill

Just like learning a new language, a musical instrument,
or a sport, teaching is a skill that requires practice and feedback.
We will have many opportunities to practice and give each other feedback throughout this workshop.

### Creating a Positive Learning Environment

One part of making this a productive experience for all of us is a
community effort to treat one another with kindness and respect.  The [Code of Conduct][coc] 
is one piece of this. We will also be discussing and practicing teaching techniques to create a positive and
welcoming environment in your classrooms, and will spend some time talking about why this is important.

### The Carpentries History and Culture

In addition to the teaching practices and philosophy that have been
adopted by The Carpentries community, it is helpful to become familiar
with our community structure and organisational procedures as you
prepare to join our Instructor community.
The greatest asset of The Carpentries is people like
you - people who want to help researchers learn new skills
and share their own experience and enthusiasm.  Meeting your fellow trainees and
Instructor Trainers at this event is your first step into The Carpentries community.

## What We Leave Out

We will **not** be going over Data Carpentry, Library Carpentry, or Software Carpentry workshop content in detail (although you will gain
familiarity with some of the content through the exercises),
This workshop is a significant requirement for becoming a certified Carpentries Instructor.
The additional steps for certification, called _Checkout_, will require that you dig into the workshop content yourself. We will talk about checkout requirements more in part 3 of this training.

We also do not discuss *how* to develop lessons, although we do mention some aspects of lesson design. We include this information to help you as an instructor identify the important components of lessons for high impact, inclusive teaching. The Carpentries now has a growing subcommunity dedicated to lesson development,
along with [its own onboarding curriculum][lesson-dev]. For more on lesson development, see [The Carpentries website][lesson-dev-web].

If there is a particular topic that you would like us to address, let the Trainers
know.

## What Questions Do You Have?

We hope and expect that you will have many questions during this training! Please do not
keep them to yourself. If you find something unclear, chances are good that others will have the same question, too.
It is ok to ask even if you think you might have missed an answer already given
(e.g. during a distracted moment or a dropped connection)!
Depending on the time available, your Trainers may ask you to share your questions
verbally, in the Etherpad, or otherwise.

Now that we have a road map of what we are covering
we are ready to begin our training. Our goal is that by the end, you will
have acquired some new knowledge, confidence, and skills that you can
use in your teaching practice in general and in teaching Carpentries
workshops specifically.

--------------------
[coc]: https://docs.carpentries.org/topic_folders/policies/code-of-conduct.html
[form-coc]: https://goo.gl/forms/KoUfO53Za3apOuOK2
[lesson-dev]: https://carpentries-incubator.github.io/study-groups/
[lesson-dev-web]: https://carpentries.org/involved-lessons/
