---
title: "Expertise and Instruction"
block: "How Learning Works"
teaching: 20
exercises: 25
questions:
- "Does subject expertise make someone a great teacher?"
- "How are we (as Instructors) different from our learners and how does this impact our teaching?"  
objectives:
- "Explain what differentiates an expert from a competent practitioner." 
- "Describe at least two examples of how expertise can help and hinder effective teaching."
- "Identify strategies for becoming aware of your expert awareness gap."
- "Demonstrate strategies for avoiding dismissive language."
keypoints:
- "Experts face challenges when teaching novices due to expert awareness gaps."
- "Things that seem easy to us are often not experienced that way by our learners."
- "With practice, we can develop skills to overcome our expert awareness gaps."
---

## Examining Your Expertise
In the last episode, we discussed the transition from novice to competent practitioner through 
formation of a functional mental model. We now shift our attention to experts. The expert we want to talk about is you!
  
Even if you do not yet think of yourself as an expert, you may nonetheless have
advanced to the point where some of these key characteristics -- and potential pitfalls -- apply to you. 
We will discuss what distinguishes expertise
from novices/competent practitioners, how being an expert can make it
more difficult to teach novices, and some tools to help instructors
identify and overcome these difficulties.  

## What Makes an Expert?  

An [earlier topic]({{ page.root }}/02-practice-learning/) described a key
difference between novices and competent practitioners. Novices lack a mental model, or have only
a very incomplete model with limited utility.
Competent practitioners
have mental models that work well enough for most situations.
How are experts different from both of these groups?

> ## What Is An Expert?  
> What is something that you are an expert in? How does your experience
> when you are acting as an expert differ from when you are not an expert?  
>
> This discussion should take about 5 minutes.
{: .challenge}

In reviewing the answers to the question above you will find that the expert 
experience amounts to much more than just knowing more facts. 
Competent practitioners can memorize a lot of information
without any noticeable improvement to their performance. 
So, what makes an expert? The answer is that 
experts have **more connections among pieces of knowledge** that help them think and problem-solve quickly;
more "short-cuts", if you will.  

![Three collections of six circles. The first collection is labelled "Novice" and has only two arrows connecting some of the circles. The second collection, labelled "Competent Practitioner" has six connecting arrows. The third collection, labelled "Expert", is densly connected, with eight connecting arrows.](../fig/mental_models.svg)

This brings us back to our mental model diagrams,
where facts are nodes and relationships are arcs.
The greater connectivity of a mental model allows experts to:

* see connections between two topics or ideas that no one else can see
* see a single problem in several different ways
* know how to solve a problem, or "what questions to ask"
* jump directly from a problem to its solution
because there is a direct link between the two in their mind.
Where a competent practitioner would have to reason
"A therefore B therefore C therefore F",
the expert can go from A to F in a single step ("A therefore F").

We will expand on some of these below and how they can manifest in the way you teach.

## Expertise and Teaching

Because your learners' mental models will likely be less densely connected than your own,
a conclusion that seems obvious to you will not seem that way to your learners.  It is important
to explain what you are doing step-by-step, and how each step leads to the next one.

### Mind The Gap

The problem with this is that when you are used to going from A to F in a single leap, it can 
be very hard to remember that novices need to go through steps B and C before they can understand the 
connection between A and F. Experts are frequently so familiar with their subject 
that they can no longer imagine what it is like to *not* understand the world that way. 
This phenomenon is known in the literature as an *expert blind spot*.

> ## Expert Awareness Gap
>  
> In The Carpentries, we aim to create an inclusive environment. We prefer to refer to this
> phenomenon as the *expert awareness gap* to be consistent with our objective to use
> inclusive language. It can be exclusionary to use a term that relates to a disability
> for other purposes. We introduce both terms, however, to help you as future
> instructors engage with these ideas in
> the literature and with people outside of The Carpentries community.
>
> In evaluating potential terms, one instructor provided the following thoughts:
>
> I like expert awareness gap because it is more precise than blind spot
> (it is not about seeing, but about noticing) and feels more of a surmountable
> challenge than a disadvantage. To me a disadvantage can sometimes feel like a
> thing that exists as a fact, like an inevitable consequence, but a gap is a
> thing to be bridged-- and we certainly want instructors to try to overcome
> (or mitigate) their expert awareness gap
>
{: .callout}

Awareness gaps can lead to some interesting reversals in the classroom. While deep expertise in a subject 
area can be valuable when teaching, it can also create obstacles that must be overcome with practice. 
People with less expertise, who still remember what it is like to have to learn the things, can 
be better equipped to anticipate novice misconceptions compared with an expert who has not learned 
to identify their awareness gaps. 

What does this mean for you? If you have deep expertise in the subject you are hoping to teach, listen 
carefully to your learners, and seek out less-expert colleagues to discuss your teaching plans. 
If, on the other hand, you still feel new to your subject area -- perhaps you even feel a little 
tentative about whether you are "expert enough" to teach -- take heart! Your explanations may 
be more likely to meet novice learners where they are.

> ## Awareness Gaps
>
> 1. Is there anything you are learning how to do right now?  Can you identify
> something that you still need to think about, but your teacher can do without
> thinking about it?  
> 2. Think about the area of expertise you identified for yourself earlier.  What could a
> potential awareness gap be?   
> 
> This exercise should take about 5 minutes.
{: .challenge}

### Switching Language

If you worked in the USA in the same building as something called a "delicatessen", 
you might invite a friend to meet you at "the deli" or simply at
"the restaurant" and expect them to know what you mean, because you naturally use these terms interchangeably. 
Yet, someone less familiar with US English might hesitate, wondering if 
these words mean the same thing, or close enough, under the circumstances. Similarly, 
in a Carpentries workshop, an Instructor may start a workshop talking about "Unix," but 
then automatically start using words like "bash" and "shell" 
without noticing that learners are struggling to figure out how these 
two new words are related.

Novice learners can be confused by interchangeable use of more than just vocabulary. 
In programming, multiple forms of notation may be 
used to reference a column in a data frame, for example, with the same effect. 
Instructors may use absolute file paths in one place, then default to relative file paths 
elsewhere without noticing that explanation is required. Or, they may assume that a learner 
who has an absolute file path will be able to navigate to the file in a GUI.

> ## What do you use interchangeably?
>
> In the Etherpad, share an example of words or notation that you sometimes use to accomplish or refer to the same thing.
> If possible, try to think of an example that might occur in a Carpentries workshop.
>
> Building awareness of how you can represent the same concept in multiple different ways
> will help you avoid doing so without explanation while teaching.
>
> This exercise should take about 5 minutes. 
{: .challenge}

### What Problem?

Experts are also better at diagnosing errors than novices or competent practitioners. If faced with an
error message while teaching, an expert will often automatically diagnose and solve a problem
before a novice has even finished reading the error message. Because of this, it is very important
while teaching to be explicit about the process you are using to engage with errors, even if they
seem trivial to you, as they often will.

> ## Diagnosis 
>
> What is an error message that you encounter frequently in your work? (These are often syntax errors.)
> Take a few minutes to plan out how you would explain that error message to your learners. Write the
> error and your explanation in the Etherpad.
>
> This discussion should take about 5 minutes. (Optionally, this may be discussed in group breakouts, adding 5 minutes.)
{: .challenge}


## "Just" and Other Dismissive Language
Instructors want to motivate learners! We will talk more about motivation in a later episode. But here, 
we will take a moment to recognize one *ineffective* strategy often deployed by experts who 
want learners to *believe that a task is as easy as they think it is.* This often manifests 
in using the word "just" in explanations,
as in, "Look, it is easy, you just... (*wave magic wand with undecipherable incantations*)"
This language gives learners the very clear signal
that the person helping them thinks their problem is trivial
and that there must be something wrong with them if they do not experience it that way. 

With practice, we can change the way we speak to avoid dismissive language and replace
it with more positive and motivating word choices.

> ## Changing Your Language  
>
> 1. What other words or phrases, besides "just", can have the same effect of dismissing the experience of finding a subject difficult or unclear? 
> 2. Propose an alternate phrasing for one of the suggestions above.
> 
> Write your examples and alternatives in the Etherpad.
>
> This exercise should take about 5 minutes.  
>
>> ## Solution  
>> It is hard to break the habit of trying to convince learners that a task is "easy"! A few alternatives 
>> might include statements like:
>> - "This task will become really easy once you have learned how to do it."
>> - "We only need to learn two new commands to accomplish the next task."
>> - "This task may feel like it will take you all year to learn, but in my experience it will take you a lot less time than that to master it."
>>
> {: .solution}
{: .challenge}

### "Any Questions?"

Another well-intended move that can go wrong in the presence of awareness gaps is the call for questions. 
An Instructor may accidentally dismiss learner confusion by asking for questions in 
a way that reveals that *they do not actually expect that anyone will have them*. Asking, "Does anyone have 
any questions?" implies that most people will not; the shorter the wait time before 
moving on, the more this implication is magnified. 
Instead, consider asking "What questions do you have?" and leaving a healthy pause for consideration. 
This firmly establishes an expectation that
people will, indeed, have questions, and should challenge themselves to formulate them.

## You Are Not Your Learners  

As you seek to re-acquaint yourself with the novice experience, it can be tempting to think back to your own 
experiences getting started in programming. Trips down memory lane can be productive! However, it is important that 
you take care not to generalize from your experience to that of your novice learners. 

We will talk more about knowing your audience in a later episode. For now, here are 
two points to keep in mind when contemplating the learner experience 
- In most cases a researcher's **primary goal is not to learn programming**, but to do better and more efficient research.
They may not wish to take the time to learn how fundamental syntax or data structures work, or 
to learn any 'fun facts' that are not strictly necessary; they just want to know how to get their work done. 
This does not mean they never will be interested -- maybe this is how you got your start, too! But if you 
began with an interest in programming, keep in mind that this can make their learning experience very different 
from yours. 
- Some researchers have avoided learning programming previously because they believe that the time investment 
will be excessive and will interfere with their other work. These kinds of beliefs can make their motivation to 
persevere more fragile than yours might have been when you got started. 


> ## The Carpentries Is Not Computer Science  
>
> Many of the foundational concepts of computer science,
> such as computability,
> are difficult to learn and not immediately useful.
> This does *not* mean that they are not important,
> or are not worth learning,
> but if our aim is to convince people that they can learn this stuff,
> and that doing so will help them do more research faster,
> they are less compelling than things like automating repetitive tasks.
{: .callout}

## Expert Advantages

As we have seen, the high connectivity of an expert's mental model poses challenges while teaching
novices. However, that is not to say that experts cannot be great teachers!  Because of their well-connected 
knowledge, self-aware experts are well-poised
to help students make meaningful connections, to confidently
turn an error into a learning opportunity, or to explain
a complex topic in multiple ways. Experts can
be highly effective as long as they **learn to identify and correct
for their own expert awareness gaps**. Whether or not you identify as an expert, we hope this episode has started you on the 
path toward developing that skill.

## The Importance of Practice (Again)

How can you make sure that expert awareness gaps are not negatively affecting your workshop? 
Keep in touch with your learners through frequent formative assessment! If you stumble 
into an expert awareness gap, create confusion by using interchangeable terms, or 
accidentally discourage rather than inviting questions, formative assessment has the power 
to bring these problems to the surface. As you develop teaching skill, you may be able 
to avoid these pitfalls. Until then, becoming aware of when they occur will help you to 
keep their impact under control. 
