---
title: "Memory and Cognitive Load"
block: "How Learning Works"
teaching: 20
exercises: 25
questions:
- "What is cognitive load and how does it affect learning?"
- "How can we design instruction to work with, rather than against, memory constraints?"
objectives:
- "Remember the quantitative limit of human memory." 
- "Distinguish desirable from undesirable cognitive load." 
- "Evaluate cognitive load associated with a learning task."
keypoints:
- "Most adults can store only a few items in short-term memory for a few seconds before they lose them again."  
- "Things seen together are remembered (or mis-remembered) in chunks."  
- "Cognitive load should be managed through guided practice to facilitate learning and prevent overload."
- "Formative assessments can help to consolidate learning in long-term memory."
---

In our final topic in how people learn (and therefore, how we can be more
effective instructors), we will be learning more about human memory:
specifically, how to remove unnecessary "load" in order to facilitate learning.

## Types of Memory

Learning involves memory. For our purposes, human memory can be divided into two different
layers.
The first is called **long-term**.
It is where we store persistent information like our friends' names and our home address.
It is essentially unbounded
(barring injury or disease, we will die before it fills up)
but it is slow to access.

Our second layer of memory is called **short-term**. This is the
type of memory you use to actively think about things and is often called working memory. It is much faster, but also much
smaller: in 1956, George Miller estimated that the average adult's short-term memory could hold
**[7±2 items][wikipedia-7]** for a few seconds before things started to drop out.
This is why phone numbers are typically 7 or 8 digits long:
back when phones had dials instead of keypads,
that was the longest sequence of numbers most adults could remember accurately
for as long as it took the dial to go around and around.

More recent research suggests that short-term memory is actually even smaller than this.
Regardless of its exact size, which may differ across people and contexts, we know that
short-term memory is limited. This has important implications for teaching. If we present
our learners with large amounts of information, without giving them the opportunity to
practice using it (and thereby transfer it into long-term memory), they will not retain
the material as well as if we present small amounts of information interspersed with
practice opportunities. This is yet another reason why going slowly and using
frequent formative assessment is important.

> ## Test Your Working Memory
>
> This website implements a short test of working memory:
> [https://miku.github.io/activememory/][memory-test]  
>
> What was your score? If you are comfortable, share your answer
> in the Etherpad.
>
> If you are unable to use this activity, ask your Trainer to implement the analog version of this test.
> 
> This exercise should take about 5 minutes.
{: .challenge}

> ## Test Your Working Memory - Analog version (5 min)
>
> Read the following list and try to memorize the items in it:
>
> cat, apple, ball, tree, square, head, house, door, box, car, king,
> hammer, milk, fish, book, tape, arrow, flower, key, shoe
>
> Without looking at the list again, write down as many words from the list as
> you can. How many did you remember? Write your answer in the Etherpad.
> 
> ## Accessibility Adaptation
> The list above may also be read aloud, slowly and clearly, by the Trainer hosting the session. 
> On your mark, ask learners to write down their answers where others cannot see them, then read the list 
> again so they can check their work.
{: .challenge}

Most people will have found they only remember 5-7 words. Those who 
remember less may be experiencing distraction, fatigue, or (as we will learn shortly) "cognitive overload." 
Those who remember more 
are almost invariably deploying a *memory management strategy*.

## Strategies For Memory Management

Because short-term memory is limited, we can support learners by not flooding their
short term memory with too many separate pieces of information. Does this mean we should 
teach fewer concepts? Yes! However, this is not the only tool in our toolbox. 
We can also assist by providing strategies
and exercises to help them form the connections that will a) support them in holding more 
things in short-term memory at once and b) begin to **consolidate** some concepts, moving them into
long-term memory.

### Chunking

Our minds can store larger numbers of facts in short-term memory by creating *chunks*, or
relationships among separate items, allowing them to be remembered as a single item.
For example, most of us will remember a word we read as a single item ("cat"), rather
than as a sequence of letters ("c-a-t").
Similarly, the pattern made by five spots on cards or die is remembered as a whole
rather than as five separate pieces of information.

> ## Improving Short-term Memory with Chunking
>
> Repeat the memory exercise you did earlier, but this time,
> try to form short stories or phrases, or a visual image, from the words you see.
>
> Write the number of words you remembered in the Etherpad.
> How does this compare with your first attempt?
> 
> This exercise should take about 5 minutes.
{: .challenge}

![A list of words: cat, apple, ball, tree, square, head, house, door, box, car, king, hammer, milk, fish, book, tape, arrow, flower, key, shoe. 
Underneath, the same words are organized into boxes with related terms e.g. cat fish milk ball and apple flower tree"](../fig/chunking.svg)

Associating concepts 
reduces the number of effective
items in your short-term memory, allowing you to keep
more information in your head at once. 

You may have come across other mnemonic strategies, including some that rely on imagining a 
"place" association for each item, e.g. a "memory palace." While slightly different from 
chunking, this is another example of how 
**connecting information can make it easier to remember**.


### Using Formative Assessment to Support Memory Consolidation

Formative assessment is a key component in helping learners solidify their understanding
and begin transferring ideas into long-term memory. Why? Because it engages the brain in 
retrieving recently-learned information and actively applying it to solve a problem. This helps 
to both reinforce and connect that new information in useful ways.

The limitations of short-term 
memory are one reason why **assessments should be frequent**: short-term memory is limited not only in 
space, but also in time. If you wait too long before deploying a formative assessment,
some of the information necessary to complete the task will already be forgotten. This time window can be very short, 
especially if a lot of content is being taught at once! Be sure to remind learners about prior concepts 
essential to a task. When you no longer need to remind them, this is a sign that your efforts in 
supporting memory consolidation have worked!

### Group Work

**Elaboration**, or explaining your work, supports transfer 
to long-term memory. This is one reason why **teaching is one of the most effective ways to learn**! 
Group work can feel uncomfortable at first and consumes time in a workshop, but 
learners often rate group work as a high point for both enjoyment and learning in a workshop. 
This is also a great opportunity for helpers 
to circulate and address lingering questions or engage with more advanced discussions.

### Opportunities for Reflection

Reflection is another tool that can help learners review things they have 
learned, strengthen connections between them, and consolidate long-term memories. Like 
formative assessment, **asking 
learners for feedback can double as both a source of information and an effective consolidating 
prompt**, as providing feedback demands some reflection on what has been learned. We will talk 
more about methods for this in the next section. You may also wish to pause 
and allow learners to write summary notes for themselves or otherwise ask them to review 
what they have learned at various points in the workshop.

### Limit concepts

In the same vein as "going slowly," it is important to limit the number of
concepts introduced in a lesson. This can be hard! As you are reviewing a lesson 
to teach, you will doubtless come across related concepts that are very useful, and 
you may feel strongly motivated to sneak them in. 
Planning your lesson with a concept map can help you 
not only identify key concepts and relationships, but also to notice when you are trying to 
teach too many things at once. 


## Attention is a Limited Resource: Cognitive Load

Memory is not the only cognitive resource that is limited. Attention is constrained as well, which can 
limit the information that enters short term memory in the first place as well as interfere with attempts 
at consolidation. 
While many people believe that they can "multi-task," the reality is that attention can 
only focus on one thing at a time. Adding items that demand attention adds more things 
to alternate between attending to, which can reduce efficiency and performance on all of them.

### The Theory of Cognitive Load

There are different [theories of cognitive load][wikipedia-cognitive-load]. In one of these, [Sweller posits that people have to attend to three types of things when they are learning](https://doi.org/10.1207/s15516709cog1202_4):

*   Things they have to think about in order to **perform a task** ("intrinsic").
*   Mental effort required to **connect the task** to new and old information ("germane").
*   **Distractions** and other mental effort not directly related to performing or learning from the task ("extraneous").

Cognitive load is not always a bad thing! There is plenty of evidence that *some* difficulty is desirable 
and can increase learning. However, there are limits. Managing all forms of cognitive load, with particular 
attention to extraneous load, can help prevent **cognitive overload** from impeding learning altogether. 

One way to manage cognitive load as tasks become more complex is by using **guided practice**: 
creating a structure that narrowly guides focus on specific skills and knowledge in a stepped fashion, with feedback at each step before 
transferring attention to a new feature.

> ## Is Guided Practice "Hand Holding?"
>
> An alternative to guided practice is a *minimal guidance* approach, where
> learners are given raw materials (for example a text or reference) and
> asked to explore and learn to solve problems on their own.
> Minimal guidance is commonly found in many instructional strategies you may have encountered, 
> variously known as *constructivist*, *discovery*, *problem-based*, *experiential*
> or *inquiry-based* learning.
>
> These strategies are not without merit! Indeed, they can work exceptionally well with advanced learners.
> However, they frequently fall flat, especially with novice audiences. 
> A landmark paper by [Kirshner et al.][kirschner-paper] 
> responds to the popularity and uneven success of minimal guidance, applying 
> cognitive load theory to understand why these strategies often fail.
>
> Some people feel concerned that guided practice amounts to "hand-holding," 
> implying that learners who receive support may never learn 
> to function independently. This view fails to account for the *additional cognitive 
> load* experienced by novices creating new connections while learning a task. 
> **Minimally-guided instruction requires learners to simultaneously
> master a domain's factual content
> AND its search and problem-solving strategies.** Fostering creativity and independence takes time.
> Minimal guidance is intuitively appealing,
> but that does not mean it always works.
{: .callout}

> ## Mapping Cognitive Load
>
> Look in the curriculum that you chose to prepare for this workshop and focus on one step or task 
> that learners will be asked to complete.  
> 1. What concepts will learners need to understand and hold in short-term memory in order to complete this task?  
> 2. Draw a concept map connecting these concepts. What relationships do learners need to understand to connect them?  
> 3. How many of these concepts and relationships have been introduced since the previous step or exercise?  
> 
> With a partner or in small groups, discuss what you have found. Are your learners at risk of cognitive overload at this point in your workshop? Why or why not?
> 
> This exercise should take about 15 minutes.
{: .challenge}


## Attention Management in Your Workshop
Carpentries lessons include small tasks arranged incrementally 
which are intended to be completed together, through participatory live coding (a technique we will discuss in more detail 
later in this training). 

The choices you make as an Instructor may add to or subtract from your learners' cognitive load. Supporting memory consolidation 
can reduce load later on in the workshop, as it reduces the effort of recalling forgotten material. You can also minimize 
cognitive load by choosing formative assessments that are 
narrowly focused and by considering potential distractions in what you display during instruction.

### Using Formative Assessments for Memory Management

There are
many different types of exercises that can focus attention narrowly and help to avoid cognitive overload. 
Carefully targeted multiple choice questions can play this role. 
A few more that you may wish to consider are:
* [Faded examples][wikipedia-faded]: worked examples with targeted details "faded" out -- essentially fill-in-the-blank programming blocks
* [Parson's Problems][wikipedia-parsons]: out-of-order code selection & sorting challenges
* Labelling diagrams or flow charts (may also be organized as a fill-in-the-blank)

Beware assessments that are too open-ended, as these are very likely to induce cognitive overload in novice learners! You may have experienced 
some overload already when you were asked to create a concept map; this is why we do not recommend these as an activity for novice learners. Questions 
that ask learners to both remember and synthesize or reason with new information are also risky. If you try out 
a question and get a room filled with silence, you may need an icebreaker, you may need to re-teach... or you may only need a more narrowly focused question.


### What to Display

The Carpentries provides nicely formatted curricula for teaching. However, you may have noticed that you have not seen much, or perhaps 
any of the Instructor Training curriculum during your time as a learner in this workshop. In most situations **we do not recommend 
displaying Carpentries curriculum materials** to your learners while you teach. 

The visual environment in a workshop should be focused on exactly what you are teaching and should mirror, 
as closely as possible, exactly what you say. 
This is because keeping track of distracting and contradictory sensory information adds to cognitive load. 
The **[split-attention effect][wikipedia-split-attention]** describes the cognitive effort involved with 
trying to assemble information from different modalities. Learning is most effective when visual 
displays, text, and auditory information presented together
are the same, with minimal distractions. 

For Carpentries workshops, this is why we ask Instructors to **speak commands as they type them on the screen** 
while engaging learners in [participatory live coding]({{ page.root }}/17-live/).

One thing you may wish to consider adding to your (otherwise minimalist) visual environment, however, is a **running glossary of commands** 
and other key terms. This can be maintained by a helper on a white board or an easel pad and will help learners readily access 
items that may have already been dropped from short-term memory by the time they need them. In an online workshop, display of a glossary 
is impractical because of severe limitations on screen space; however, a glossary can still be maintained in a collaborative document 
for reference as needed.


## Summary
The process of learning is constrained by the limits of short-term memory. In order to move
new information into long-term memory, it must be actively applied, but activities that
make excessive demands on short-term memory are likely to induce cognitive overload and can
easily harm learner motivation. Instructional tools that expand short-term memory by
increasing connectivity (chunking) among new concepts can improve
outcomes for subsequent memory-intensive exercises. Formative assessments, when performed
frequently, help learners by prompting them to apply new content before it has been
overwritten. Faded examples or other types of guided practice
both minimize demands on short-term memory and offer context that
helps improve connectivity for future work, in which the "scaffolding" of contextual support
can be gradually removed.
Anything you can do to a) recognize and b) support learners in working with the
limitations of short-term memory will improve the effectiveness of your teaching.

[kirschner-paper]: https://www.tandfonline.com/doi/pdf/10.1207/s15326985ep4102_1
[memory-test]: https://miku.github.io/activememory/
[wikipedia-cognitive-load]: https://en.wikipedia.org/wiki/Cognitive_load
[wikipedia-inquiry]: https://en.wikipedia.org/wiki/Inquiry-based_learning
[wikipedia-split-attention]: https://en.wikipedia.org/wiki/Split_attention_effect
[wikipedia-7]: https://en.wikipedia.org/wiki/The_Magical_Number_Seven,_Plus_or_Minus_Two
[wikipedia-faded]: https://en.wikipedia.org/wiki/Worked-example_effect
[wikipedia-parsons]: https://en.wikipedia.org/wiki/Parsons_problems

