---
title: "Motivation and Demotivation"
block: "Creating a Positive Learning Environment"
teaching: 30
exercises: 30
questions:
- "Why is motivation important?"
- "How can we create a motivating environment for learners?"
objectives:
- "Identify authentic tasks and explain why teaching them is important."
- "Develop strategies to avoid demotivating learners."
- "Distinguish praise based feedback on the type of mindset it promotes."
keypoints:
- "A positive learning environment helps people concentrate on learning."
- "People learn best when they see the utility in what they're learning and believe it can be accomplished with reasonable effort."
- "Encouraging participation and embracing errors helps learners to stay motivated."
---
## Motivation Matters
Teaching and learning are not the same process. As we have seen, an instructor can make choices that facilitate the cognitive processes
necessary for learning to occur. But **any technique can fall flat when learners are not motivated**. Worse, demotivation is contagious! Teaching or sharing a classroom with demotivated 
learners is not fun or rewarding. It can be tempting, especially for teachers facing burnout after strenuous and ineffectual effort, to blame learners for 
spoiling the classroom experience.

It is true that learner motivation is influenced by many factors well beyond the control of an instructor, including individual background and systemic forces.
However, there are many things you can do to cultivate motivation in your classroom, and perhaps most importantly, to **avoid doing harm** to the precious drive your 
learners bring to the classroom on day one. In Carpentries workshops, most learners come eager to learn! You have the power to influence how they feel when they depart.

No two-day workshop can truly bring a total novice to the level of a competent practitioner. Carpentries workshops function in a context of 
*self training*, in which workshops offer vital tools and a map for learners to proceed on their own. Our workshops lower the barrier to entry and help learners 
to get off on the right foot. In this context, **cultivating motivation to continue learning, and to carefully pursue best-practices in doing so, is arguably the 
most important outcome we can achieve**.

This section discusses several ways that
learners can be motivated (or demotivated!) by instructional content and approaches, and provides practice opportunities
for you to become confident in motivating your learners.

## How Can Content Influence Motivation?

People learn best when they care about a topic and believe they can master it with a reasonable investment of time and effort.
Many scientists might appreciate the value of programming
but believe that developing useful skills will take more time than they have available.
This presents a problem because **believing that something will be too hard
to learn often becomes a self-fulfilling prophecy**.

One way to combat this problem is to begin a lesson with something that is **quick to learn and immediately useful**. 
It is particularly important that *learners* see it as useful in their daily work.
This not only motivates them,
it also helps build their confidence in us,
so that if it takes longer to get to something they find useful in a later topic,
they will persist with the lesson.

Imagine a graph whose axes are labelled "mean time to master" and "usefulness once mastered".
Tasks that are quick to master and immediately useful should ideally be taught first;
things in the opposite corner
that are time-consuming to learn and have little near-term application
should be avoided in our workshops.


![A stylized graph with y-axis labeled "usefulness once mastered" and and x-axis labeled "mean time to master". The upper left quadrant says "teach this first" and the lower right quadrant says "do not bother".](../fig/what-to-teach.png)

Another way to think about the graph shown above is **authentic tasks** -- real tasks performed
by someone doing their work. If you can identify authentic tasks from your
own work that could be useful to others, these examples will be highly
motivating.


> ## Authentic Tasks: Think, Pair, Share
>
> **Think** about some task you did this week that uses one or more of the skills we teach,
> (e.g. wrote a function, bulk downloaded data, built a plot in R, forked a repo)
> and explain how you would use it (or a simplified version of it) as an exercise or example in class.
> **Pair** up with your neighbor and decide where this exercise fits on a graph of "short/long time to master" and "low/high usefulness". 
> In the class Etherpad, **share** the task and where it fits on the graph.
> As a group, we will discuss how these relate back to our "teach most immediately useful first" approach.
>
> This exercise should take about 10 minutes.
{: .challenge}

> ## Actual Time
>
> Any useful estimate of time must take into account
> **how frequent failures are**
> and how much time is lost to them.
> For example,
> editing a text file seems like a quick task,
> but most graphical editors save things to the user's desktop or home directory.
> If a novice needs to run shell commands on the files they've edited,
> they often fail to navigate to the right directory without help.
> You will learn to anticipate these sorts of challenges as you chart your [expert awareness gaps]({{ page.root }}{% link _episodes/04-expertise.md %}#expertise-and-teaching). As a result, your skill at estimating time to mastery will improve.
> If you are new to teaching, try to ask an experienced instructor for feedback before trying out a new exercise.
{: .callout}


While we aim to begin workshops with motivating content, in practice this does not always occur. Workflow-based content like that taught in Data Carpentry
workshops may start at the beginning of the workflow, for example. Even when a 'motivating example' is built in to the start of a workshop, technical 
problems like software installation can turn those precious first minutes into an experience of frustration and impatience. That is ok! What is important is to
**be mindful of times when your content is not motivating**, and to strategize your rescue using some of the other techniques in this section.

## How Can You Affect Motivation?

In addition to teaching things that will make our learners' lives easier and focusing
on authentic tasks, there are a number of other strategies we can use to motivate
learners when we teach.

> ## Brainstorming Motivational Impacts
>
> Think back to courses you have taken in the past and consider things that an instructor has said or done that you found either **motivating** or **demotivating**. 
> Try to think of one example in each case, and share your example under the appropriate heading in the Etherpad.
>
> This exercise should take about 5 minutes.
{: .challenge}

### Invite Participation

Motivation is supported by active engagement. Participation allows learners to ask questions, resolving roadblocks quickly, and demonstrate knowledge, building 
confidence. It also facilitates learning! However, in a room full of strangers, **most learners will not immediately feel comfortable speaking up**, especially when they feel 
confusion or doubt. Creating a motivating classroom means inviting communication and reinforcing that invitation with an attentive response.

A few ways to invite participation are:

+ **Establishing norms for interaction**. This can be done by creating procedures for communication, e.g. turn taking in discussions, passing around a 'talking 
stick', or encouraging quieter people to contribute. Having, discussing, and enforcing a [Code of Conduct](https://docs.carpentries.org/topic_folders/policies/code-of-conduct.html) 
also provides a framework for positive communication to occur. 
+ **Encouraging learners to learn from each other**. Working in pairs, or "[pair programming](https://en.wikipedia.org/wiki/Pair_programming)," encourages 
learners to talk through their learning process, reinforcing memory and making it more likely that confusion will be expressed and 
resolved. This can also address challenges of varying background experience: asking more advanced learners to help beginners can 
maximize learning for both. In these cases, make sure the beginner is doing the typing!
+ **Acknowledging when learners are confused**. Acknowledging and exploring confusion with kindness rewards learners for sharing vulnerable information. It also 
helps you examine your expert awareness gaps! Formative assessments can pinpoint misunderstandings. When learners see  that others are confused, they are more likely to share their own uncertainties.

### Encourage a Growth Mindset

People vary in their beliefs about the nature of intelligence and skill development. In academic environments, people 
are often praised as "talented" or having "high ability," and may develop an identity around being a certain "type of 
person" who has inherent strengths or weaknesses.

The belief that ability or intelligence is born rather than made -- dubbed a **fixed mindset** by Carol Dweck -- may impact the learning process. Broadly, this is a
continuing topic of research and debate in education communities. In the specific context of Carpentries workshops, we frequently encounter learners who believe that they are not 
"computational people," and Instructors often report that this fixed mindset interferes with motivation to engage fully with the task of learning to program. We 
therefore recommend three types of interventions that have been shown to influence mindset, encouraging learners to believe that ability can be acquired through 
effort -- a **growth mindset**.

+ **Positive error framing**. Errors are inevitable when learning a new skill. However, learners will often interpret errors as indicators of 
inability -- adopting a fixed mindset. Encouraging learners to understand errors in a positive way -- as an opportunity to learn something they would have missed 
otherwise -- reinforces a growth mindset and helps them to stay motivated. Be sure to discuss this with your helpers, since they are 
often the 'first responders' to learner mistakes. 


> ## Helping Learners Learn From Mistakes 
> A learner at your workshop asks for your help with an exercise and shows you their attempt at solving it. You see they've made an error
> that shows they misunderstand something fundamental about the lesson (for example, in the shell lesson, they forgot to put a space between
> `ls` and the name of the directory they are looking at). What would you say to the learner?
>
> In the Etherpad, describe the error your learner has made and how you would respond.
>
> This exercise should take about 5 minutes.
{: .challenge}


+ **Presenting the instructor as a learner**. We want our learners to have confidence in our qualifications, but it is easy to take this too far. Presenting yourself as a learner offers a relatable model, fostering a growth mindset and teaching a positive approach to the continuing challenge of learning. Using 
[participatory live coding]({{ page.root }}/17-live/), our chosen method for teaching concepts, is very useful for this reason. It is common to make errors while 
coding. Embrace these with enthusiasm! Leveraging your own mistakes as opportunities can turn an awkward moment into a highlight of a lesson, demonstrating both 
problem-solving approaches and positive error framing. If you are unlucky and fail to make any useful mistakes, sharing stories about your learning process can 
help here, too.

> ## Typos
> The typos are the pedagogy.
> — Emily Jane McTavish
{: .testimonial}

+ **Praising effort or improvement, not performance or ability**. Praise based on the quality of performance often feels like the highest praise because it goes 
straight to your identity as a person of intellect and skill. When faced with a fixed mindset ("I'm not a computational person!"), many well-intentioned teachers 
counter with another fixed mindset ("You ARE a computational person! You're really good at this!"). However, this doesn't prepare learners to interpret future obstacles as 
irrelevant to innate ability. Evidence suggests that learner perseverance is best supported in the long term by praising effort or improvement instead. If you 
are not convinced of this, consider the impact on the person sitting next to your target, who might overhear but not receive the same praise.

> ## Choosing our Praises
> Since we are so used to being praised for our performance, it can be challenging to change the way we praise our learners. Which of these examples 
> of praise do you think are based on performance, effort, or improvement?
>
> 1. That's exactly how you do it -- you haven't gotten it right yet, but you've tried two different strategies to solve that problem. Keep it up!
> 2. You're getting to be really good at that. See how it pays to keep at it?
> 3. Wow, you did that perfectly without any help. Have you thought about taking more computing classes?
> 4. That was a hard problem. You didn't get the right answer, but look at what you learned trying to solve it!
> 5. Look at that - you're a natural!
> 
> This exercise should take about 5 minutes.
>
>> ## Solution
>> 1. Effort-based.
>> 2. Improvement-based.
>> 3. Performance-based.
>> 4. Improvement-based.
>> 5. Performance-based. 
> {: .solution}
{: .challenge}

+ **Leveraging the Power of "Yet"**. A request for help might start with "I can't ___ " or "I don't understand ___ ". Depending on the attitude of the learner, 
these can sound like statements of fact rather than requests for help! Adding the word "yet" to the end of these sentences helps emphasize that being a novice is 
a temporary state, and encourages a growth mindset towards progress. 

### First, Do No Harm!

When learning a skill, we develop more than expert awareness gaps -- we also develop Opinions about tools and methods, and sometimes base a professional identity 
around displaying technical expertise. Technical boasts, insults, and other showy moves can score points in conversation with fellow experts, but these present 
serious hazards in the classroom! Here are a few **things you should not do in your workshop:**

*   **Talk contemptuously or with scorn about any tool or practice**, or the people who use them. Regardless of
    its shortcomings, many of your learners may be using that tool, and may have invested many years in learning to do so.
    Convincing someone to change their practices is much harder when
    they think you disdain them. 
*   **Dive into complex or detailed technical discussion** with the one or
    two people in the audience who clearly don't actually need to be
    there. Reserve those conversations for breaks or follow-up emails.
*   **Pretend to know more than you do**.  People will actually trust you
    more if you are frank about the limitations of your knowledge, and
    will be more likely to ask questions and seek help. (Also see "Presenting the instructor as a learner," above)
*   **Use the J word ("just") or other demotivating words** we talked about in a
    [previous lesson]({{ page.root }}/04-expertise/). These signal to the learner that
    the instructor thinks their problem is trivial
    and by extension that they therefore must be deficient
    if they are not able to figure it out.
*   **Take over the learner's keyboard**. It is rarely a good idea to type anything for your learners.
    Doing so can be demotivating for the learner (as it implies you don't think they can do it themselves or
    that you don't want to wait for them). It also wastes a valuable opportunity for your learner to develop muscle memory and other
    skills that are essential for independent work. 
*   **Express surprise at unawareness**. Saying things like "I can't believe you don't know X"
    or "You've never heard of Y?" signals to the learner that they do not have
    some required pre-knowledge of the material you are teaching, that they don't belong at the workshop,
    and it may prevent them from asking questions in
    the future. (For more on this see the Recurse Center's [Social Rules][recurse-social-rules]).

It can be difficult to avoid these demotivators entirely. Some people are so used to
complaining about certain tools
that they initially fail to realize they're doing it while teaching. If you catch yourself doing this, you might find a way to walk it back, or consider how you might repair or improve your motivational efforts on your next interaction. Teaching yourself -- and your helpers! -- 
to avoid these types of comments takes practice, but is well worth the effort. 


## Not Just Learners

What we have not discussed yet is strategies to motivate the *instructor*. But why does *your* motivation matter?
+ **Learners respond to an instructor's enthusiasm**. The more motivated you are, the more motivated they will be!
+ **Instructors are learning to teach.** This takes motivation, too! Deliberative practice, seeking feedback, and reflecting on mistakes in the
context of your own busy work life is a challenge. What will keep you energized to stay engaged with your learning process?
+ **Carpentries Instructors teach because they want to.** Whether you are truly volunteering your time or are fulfilling a role in a job you have 
chosen, teaching is something you came here motivated to do. Teaching can be an incredibly gratifying activity! Finding and preserving your own motivation
through the many challenges ahead will make your journey as a teacher a more joyful one. 

> ## Why Do You Teach? 
>
> We all have a different motivation for teaching, and that is a really good thing!
> The Carpentries wants instructors with diverse backgrounds because you each bring something
> unique to our community.
>
> What motivates you to teach? Write a short explanation of what motivates you to teach.
> Save this as part of your teaching philosophy for future reference.
>
> This exercise should take about 5 minutes.
{: .challenge}




[ada-initiative-resources]: https://adainitiative.org/continue-our-work/impostor-syndrome-training/
[worldcat-clubhouse]: https://www.worldcat.org/title/unlocking-the-clubhouse-women-in-computing/oclc/752326915
[worldcat-hlw]: https://www.worldcat.org/title/how-learning-works-seven-research-based-principles-for-smart-teaching/oclc/762968489
[worldcat-shallow-end]: https://www.worldcat.org/title/stuck-in-the-shallow-end-education-race-and-computing/oclc/792730600
[worldcat-whistling-vivaldi]: https://www.worldcat.org/title/whistling-vivaldi-and-other-clues-to-how-stereotypes-affect-us/oclc/987873095
[conference-accessibility]: https://modelviewculture.com/pieces/unlocking-the-invisible-elevator-accessibility-at-tech-conferences
[deaf-accessibility]: https://modelviewculture.com/pieces/qa-making-tech-events-accessible-to-the-deaf-community
[four-letter-words]: https://m.signalvnoise.com/four-letter-words-f01603fb704c#.dfulbwp49
[high-achieving-women]: http://www.paulineroseclance.com/pdf/ip_high_achieving_women.pdf
[jussim-stereotype-threat]: https://www.psychologytoday.com/blog/rabble-rouser/201512/is-stereotype-threat-overcooked-overstated-and-oversold
[recurse-social-rules]: https://www.recurse.com/manual#sec-environment
[shapiro-neuberg-stereotype-threat]: http://shapiro.psych.ucla.edu/Papers_files/Shapiro%20PSPR2007.pdf
[study-com-stereotype-threat]: http://study.com/academy/lesson/stereotype-threat-definition-examples-theories.html
[swc-python-v4]: http://v4.software-carpentry.org/python/flow.html
[usenix-impostor-syndrome]: https://www.usenix.org/blog/impostor-syndrome-proof-yourself-and-your-community
[w3c-accessible]: http://www.w3.org/WAI/teach-advocate/accessible-presentations/
[webaim]: http://webaim.org/
[wikipedia-curb-cuts]: https://en.wikipedia.org/wiki/Curb_cut
[wikipedia-impostor-syndrome]: https://en.wikipedia.org/wiki/Impostor_syndrome
[wikipedia-screen-reader]: https://en.wikipedia.org/wiki/Screen_reader
[wikipedia-stereotype-threat]: https://en.wikipedia.org/wiki/Stereotype_threat
