---
title: "Equity, Inclusion, and Accessibility"
block: "Creating a Positive Learning Environment"
teaching: 20
exercises: 20
questions:
- "Why are equity, inclusion, and accessibility important?"
- "What can I do enhance equity, inclusion, and accessibility in my workshop?"
objectives:
- "Identify instructional strategies that are consistent with universal design."
- "Recognize systemic factors that can distract and demotivate learners."
- "Understand the role of The Carpentries Code of Conduct in maintaining an explicitly inclusive environment."
keypoints:
- "Inclusivity is a key attribute of a positive learning environment."
- "Universal design benefits everyone."
---

## A Positive Environment for All

As we have seen, there are many teaching practices that can make your workshop more positive and welcoming. 
However, no workshop occurs in a vacuum: everyone's experiences begin and end and are influenced by the world beyond. 
In this section we will discuss some of the systemic barriers that can result in members 
of some groups being excluded even in an otherwise welcoming environment. The fact that some groups face barriers 
that others do not means we cannot take a one size fits all approach to creating a positive learning environment. 

### Definitions

This section addresses topics related to equity, inclusion, and accessibility. These terms are increasingly common 
and may be familiar to you, but not everyone understands or interprets them in the same way. So, we will start 
with a few working definitions, adapted from the [University of Pittsburgh DEI Glossary][glossary]:

**Equity:** The proportional distribution of desirable outcomes across groups. Sometimes confused with equality, 
equity refers to outcomes while equality connotes equal treatment. 

**Inclusion:**  Actively engaging traditionally excluded individuals and/or groups in processes, activities 
and decisions in a way that shares power. Inclusion promotes broad engagement, shared participation, 
and advances authentic sense of belonging through safe, positive, and nurturing environments. 

**Accessibility:** Refers to the intentional design or redesign of technology, policies, products, and services (to name a few) 
that increase one's ability to use, access, and obtain the respective item. Each person is afforded the opportunity to acquire
the same information, engage in the same interactions, and enjoy the same services in an equally effective and equally
integrated manner, with substantially equivalent ease of use. 

### The Carpentries Core Values

In 2019, The Carpentries formed a task force that worked with our community to identify 9 [Core Values][core-values] -- 
things that we do, things that we are, and things that we champion. Many of these relate to equity, inclusion, and accessibility. 

> ## Discuss The Carpentries Core Values
>
> 1. Take a moment to read through the Core Values on this page: <https://carpentries.org/values/>
> 2. Choose one core value that resonates with you. What is a decision you might make in a workshop 
> that could look different if you were actively considering the core value you chose?
>
> This exercise should take about 5 minutes.
{: .challenge}



## Accessibility

Barriers to accessibility encountered in a workshop are demotivating at best and can exclude a learner entirely. 
What barriers might be present in your workshop, and what can you do to remove them?


> ## What Happens When Accessibility is an Issue?
>
> Think of a time when you have been affected by, or noticed someone else
> being affected by barriers to accessibility. This may have been at a
> conference you attended where the elevator was out of service, or maybe
> a class you were taking relied on audio delivery of content. Describe what happened,
> how it impacted your (or someone else's) ability to be involved and what could
> have been done to provide better accessibility in this case.
>
> This exercise should take about 5 minutes.
{: .challenge}


While it may not be possible to anticipate all needs,
it *is* possible to get a good working structure in place
without any knowledge of what specific disabilities people might have.
Having some accommodations prepared also demonstrates care, helping 
learners to trust that additional requests are likely to be well received.

If you are playing the host role (or part of it), note that our [host template][handbook-host-template]
includes an inquiry regarding accessibility needs. However, be aware that **many 
people will not feel comfortable requesting accommodations in advance**, or at all if it can be avoided.
For example, a participant who is hard of hearing may simply hope that
instructors will speak loudly enough for them to hear. Taking steps to make 
your workshop maximally accessible can relieve your participants of the need to disclose personal information.

### From Accommodation to Universal Design 
Accommodation means changing things to serve an individual with a demonstrated need. 
However, **accommodation puts the onus on the individual with the need** to 
have to disclose their disability and ask for accommodations. Reluctance to 
do so is understandable: requests for accommodation are often met with negative 
emotions such as uncertainity, confusion, annoyance or anger by those receiving the requests.  

By contrast, "universal design" means creating something to be maximally usable by all people 
without additional changes. 
A good example of universal design is curb cuts
and sidewalk ramps. While they were originally created to make it easier for 
wheelchair users to move around, they proved to be equally helpful to people with strollers and grocery carts. 

![People using different wheeled devices utilising the curb cut. The picture is titled The Curb-Cut Effect and states "when we design for disabilities, we make things better for everyone."](../fig/sketchplanations-the-curb-cut-effect.png){: width="600px" }
Image: [Sketchplanations][sketchplanations-curb-cuts]

### Universal Design in Learning (UDL)

In the 1990s, the Center for Applied Special Technology (CAST) brought Universal Design 
into Education with the [Universal Design in Learning (UDL) Framework][CAST]. 
UDL places responsibility for accessibility on the course designer rather than on the learner. 
It states that the most inclusive approach to education is to design instruction with diverse learners in mind from the beginning.

UDL is not about finding the one, best way to teach everyone. 
The key to UDL is creating redundancies such that learners have multiple options in how they: 
1. receive
2. engage, and
3. share information.  

> ## Activity: Applying Universal Design in Your Teaching
> 
> Consider some of the teaching tools and strategies we have discussed so far in this workshop, or others you have observed in your experience. 
> How do these meet UDL goals of providing multiple options for learners? 
> 
> Consider multiple ways for learners to:
> - receive information
> - engage with you, the material, and other learners
> - share what they have learned
> 
> This exercise should take about 10 minutes.
> 
{: .challenge}


Wherever possible, when considering whether or how to change your approach to universal design, 
make an effort to *involve people with disabilities in decision-making*.
Carpentries communications channels can be a good place to ask for advice more broadly.


> ## Every Little Bit Counts
>
> Looking at people who work with disability and accessibility, it's
> easy to be overwhelmed by all the different ways we could make
> instruction more accessible. 
>
> *   *It is ok not to do everything at once.*
>     We do not ask learners in our workshops to adopt all our best practices or tools in one go,
>     but instead to add things gradually at a rate they can manage.
>     Similarly, try to build in accessibility habits when preparing for workshops
>     through reflective practice, adding something new each time.
> *   *Do the easy things first.*
>     There are plenty of ways to make workshops more accessible
>     that are both quick to accomplish and minimal in demands on attention:
>     font choices, text size,
>     checking in advance that your room is accessible via an elevator or ramp, etc.
{: .callout}

For a short checklist of things to keep in mind for in-person workshop locations, see [the accessibility checklist][handbook-accessibility-checklist] 
in The Carpentries Handbook. In particular, take note that the most frequent accessibility challenge noted in [Carpentries post-assessment 
surveys][post-surveys] is difficulty hearing an Instructor from the back of the room.


> ## Accessibility Testing
>
> Find the nearest public transportation drop-off point to your building
> and walk from there to your office and then to the nearest washroom,
> making notes about things you think would be difficult for a wheelchair user.
> Now borrow a wheelchair and repeat the journey.
> How complete was your list of challenges?
> And did you notice that the first sentence in this challenge
> assumed you could walk?
{: .callout}


## Systemic Exclusion

As Instructors, many aspects of our classroom environment are within our control or influence. 
However, the world is a complicated place, and there will always be extraneous factors that 
contribute to demotivation and add to cognitive load. These vary from person to person, but 
members of certain groups often carry a heavier load due to systemic forces that disproportionately 
impact them. What we can control, in this case, is our own awareness of the challenges these forces 
present to teaching and learning. As with other demotivation pitfalls, we can also
think carefully about the language that we use and how we interact with our learners to avoid reinforcing systemic bias.

### Stereotypes

We all use stereotypes, and for good reason. They serve a cognitive purpose. 
[One study][34gig] suggests we encounter more than 34 gigabytes of information every day. 
That is more information than we could ever process, so our brains use shortcuts. 
What an expert thing to do! Stereotypes are one of those shortcuts. As with other models, 
they are all wrong... but some are dangerous.

### What are stereotypes?

Stereotypes are an established feature of human social cognition, in which a set of characteristics 
is associated with members of a group. Sterotypes:
- may be explicit (conscious and deliberate) or implicit (unconscious and automatic)
- guide what we notice about people 
- guide how we interpret people's behaviors
- can facilitate quick judgements in appropriate situations (e.g. stopping a child from driving a car)
- can lead to systematically negative attitudes and behaviors towards members of certain groups 

Stereotypes are dangerous when they are explicit, but they are especially hazardous when they are implicit. This 
means that the people holding them may not be aware of them, even though their perceptions are guided by them. 

**When Instructors have stereotypes about learners**, this may lead them to:
- call attention to differences unnecessarily
- give more or less attention to certain learners
- respond to questions differently for certain learners

**When learners experience stereotypes about themselves**, they may:
- develop a fixed mindset about aspects of their own capability
- experience increased cognitive load when reminded about a stereotype, interfering with the learning process. This is known as *stereotype threat*.

## What can we do about our own stereotypes?
- Get to know people from many different groups! 
- Observe your own behavior, and build awareness of situations in which your perceptions and behaviors are influenced by stereotypes.
- Avoid calling attention to common stereotypes, even in a way that seems positive.

> ## Better Together
>
> One way to support at-risk learners of all kinds is to ask people to sign up for workshops in small teams
> rather than as individuals when possible.
> If an entire lab group comes,
> or if attendees are drawn from the same (or closely-related) disciplines,
> everyone in the room will know in advance
> that they will be with at least a few people they trust,
> which increases the chances of them actually coming.
> Furthermore,
> if people attend a workshop with their labmates, it's more likely they will
> work together to implement what they've learned after the workshop has ended.
{: .callout}

## Equity versus Equality
We can monitor our own use of stereotypes, but the experiences that people have before and 
after our workshop are beyond our control. Because these experiences are unequal, including 
historical and present-day differences in 
access to resources, mentorship, and other avenues towards career success, we aim to make Carpentries 
programs *equitable*. This means that, rather than offering the same access and experience to all, we 
aim to use our programs to actively counter-balance unequal opportunities that have led to 
disproportionate representation of certain groups in data-centric careers. 

If you host a workshop, we encourage you to consider means of reaching out to historically under-represented 
groups in your community who may be interested in attending. 


## Inclusive Practices in a Carpentries Workshop

### Setting Expectations with the Code of Conduct

One central way that The Carpentries fosters an inclusive, respectful
learning environment is our [Code of Conduct][coc].

All participants in our workshops and communities are required to abide by the
[Code of Conduct][coc].
This code helps to ensure that our community does not tolerate the persistence of behaviors 
that harm or exclude others. While such a code cannot prevent all incidents, reminding 
participants of the Code of Conduct supports them in 
being mindful of the impact of their words and actions. It also offers reassurance 
to all that the instructional team cares about their experience, creating
an environment that is explicitly inclusive and supports safe focus 
on learning.

We will discuss the Code of Conduct in greater detail in Part 4 of this training during
our discussion of Working with your team.

### Listening with Assessment and Feedback

Motivating practices like those discussed in the previous episode to invite participation and encourage a growth mindset can also 
contribute to making a classroom more inclusive for diverse learners. 
However, we cannot assume that any instructional approach has succeeded at fostering inclusion if we do not listen to our audience. 
Explicitly seeking to learn from and attend to the concerns of your learners is key. If you find yourself feeling 
uncertain about whether you are successfully including all learners, this is a good time to pause and create an opportunity 
to listen. 

When you are actively providing avenues for feedback, there are two signs of trouble to watch out for: negative feedback, and a **lack of feedback**. 
If an environment does not feel inclusive, many learners will not feel comfortable reporting this; indeed, they may not recognize it 
themselves. It can be difficult to notice the people you are *not* hearing from in a room! When in doubt, communicate with your team and 
work together to identify and (gently) check in with anyone you haven't heard from. In addition, examine your feedback processes to be sure you are 
including opportunities for **anonymous feedback**.


### Examining your Actions

When you pay close attention to your own actions, this can help you to do more than (painfully) identify how often you 
use the word "just"! Monitoring your actions can also provide you with useful information about the ways in which you behave 
differently with different people. This is normal! It is also an excellent way to identify patterns that may intefere with your 
intent to create an inclusive environment for all. Did you answer the same question in different ways at different points? If so, why? 
Who did you feel comfortable chatting with at break time, and who seemed harder to connect with? Did you offer help to anyone who 
didn't ask for it? Who were you most eager to impress?

Asking yourself questions like these is hard! Answering them is harder. 
When you notice things that trouble you, keep a positive and simple goal in mind: to learn and to improve. 


## Looking for More? Want to Contribute?
The Carpentries is actively working on improving our content and practices with respect to equity, inclusion, and accessibility. If you are interested in 
being involved in the development of this content, please let us know! Contributions to this page may be made on GitHub (click the "improve this page" link 
at the top), though our [#accessibility channel][slack-accessibility] on [The Carpentries Slack][slack-join], or by emailing [team@carpentries.org](mailto:team@carpentries.org).


[34gig]: https://ijoc.org/index.php/ijoc/article/view/1566
[glossary]: https://www.diversity.pitt.edu/education/diversity-equity-and-inclusion-glossary
[coc]: https://docs.carpentries.org/topic_folders/policies/code-of-conduct.html
[core-values]: https://carpentries.org/values/
[CAST]: https://udlguidelines.cast.org
[handbook-accessibility-checklist]: https://docs.carpentries.org/topic_folders/hosts_instructors/workshop_needs.html#accessibility
[handbook-host-template]: https://docs.carpentries.org/topic_folders/workshop_administration/email_templates.html#email-learners-before-workshop
[post-surveys]: https://zenodo.org/record/1325464#.YVJIWS-B0ea
[slack-join]: https://swc-slack-invite.herokuapp.com/
[slack-accessibility]: https://swcarpentry.slack.com/archives/CBDTKM30Q
[sketchplanations-curb-cuts]: https://sketchplanations.com/the-curb-cut-effect
[wikipedia-curb-cuts]: https://en.wikipedia.org/wiki/Curb_cut
[wikipedia-impostor-syndrome]: https://en.wikipedia.org/wiki/Impostor_syndrome
[wikipedia-screen-reader]: https://en.wikipedia.org/wiki/Screen_reader
[wikipedia-stereotype-threat]: https://en.wikipedia.org/wiki/Stereotype_threat
