---
title: "Preparing to Teach"
block: "Building Teaching Skill"
teaching: 20
exercises: 25
questions:
- "How should I prepare to teach?"
objectives:
- "Create a profile for a learner in your workshop."
- "Critically analyze a learning objective for your workshop."
- "Identify checkpoints in a lesson for formative assessment."
keypoints:
- "To teach effectively, you have to know *who* you are teaching."
- "Good learning objectives identify specific events that can be evaluated through formative assessment."
- "A good exercise informs Learners and Instructors when an objective is achieved."
---
## Building Teaching Skill
In this training we have discussed many cognitive principles and teaching practices that guide the design and
implementation of Carpentries Workshops.
We hope you are feeling excited and optimistic about putting
those concepts to work!
One thing we have emphasized is that **teaching is a skill** - and a complex one at that.
Whether you are new to teaching or skilled in certain methods, adding new features takes time, effort, and deliberate practice. In this episode,
we will walk through some suggestions about how to prepare yourself for success in the classroom.

As in other sections, we will not discuss technical preparation. Carefully reviewing the content of your workshop is important!
However, **it is common for new Instructors to
over-prepare on technical content** -- which can be endless! -- and under-prepare the
learner-centered elements of their teaching practice. If you encounter questions that you can't answer,
demonstrating how you Google things may earn surprisingly positive feedback! In contrast, neglecting
to attend to the audience usually has much more serious consequences for learning and morale. When you prepare to teach,
we therefore suggest setting aside time *before* deeply reviewing your technical content to **plan your approach to instruction**.

> ## A note on cutting
>  
> This episode is a common place to Trainers to cut while preparing to teach.
>  That's not because this is not important -- this page is a valuable resource -- but we feel this
>  is one of the sections that trainees can use effectively as a resource when actually preparing
> for a workshop, even without spending a lot of time doing activities on this material during
> their Instructor Training event.
>
{: .callout}


## Anticipate Your Audience

To teach effectively, you have to know *who* you are teaching. You may have a broad idea about the type of audience you expect. You may
(we hope!) have a plan to learn a few things about your participants after a class has begun. However, in thinking about your learners, it is
also important to consider them in a broader context and in a way that you are not able to fully explore in your classroom. It can be helpful
to reserve time to think through ways in which learners' experiences and needs may be similar to or different from your own, or from each others.

![A tree diagram of Carpentries instruction and audience in which Instructor Trainers teach Instructors and Instructors teach Learners](../fig/instructor-training-program.png)


> ## Imagine a Learner
>
> Take a moment to silently imagine a learner who might attend your workshop. What is their background? What problem do they face?
> What will they gain from attending your workshop?
>
> This exercise should take about 2 minutes.  
{: .challenge}

As you strive to anticipate and understand your audience, it is
useful to recognize that you will never know everything about the individuals who come into your classroom. You will not
be informed about their hopes and fears beyond what they choose to present. You will never know the full spectrum of neurodiversity represented in your
workshop. You will not know who is going through a rough break-up, who struggles with an abusive work environment, who has a sick baby at home, or who skipped
breakfast to save money that morning. What challenges might affect your imaginary person? Thinking deeply about learners as people can help you prepare to bring your
best self and provide an inclusive environment for everyone.

### Remember Your Pre-Workshop Surveys
The Carpentries strives to create useful assessment instruments that can help you plan and understand your workshop. Pre-survey data will likely accumulate
right up to the start of your workshop. Be sure to check the links sent by The Carpentries Workshop Administration Team for the most up-to-date information
about your trainees. If you think our surveys could benefit from new or different questions, please let us know!


## Examine Learning Objectives
All Carpentries lessons should have learning objectives listed at the top of each episode. Did you notice these
in your lesson? In the most
cases they are quite specific about **what a learner should be able to do** by the end of the episode.
This is helpful in both designing extra formative assessments and in evaluating possible additions or digressions for
appropriateness.

Carpentries learning objectives should target novice learners. This typically means that the actions specified by the learning objective should be
basic and uncomplicated. These might include words like "recognize," "distinguish," or "use." They typically do not include words like "design," "evaluate," or "break down"
because these imply more complex cognitive actions even where the focal content is the same.

> ## Evaluate Learning Objectives
>
> Select one learning objective from the episode you've used for teaching practice. Copy it into the Etherpad
> then add numbers below your objective to address the following:
>
> 1. Suppose a learner had mastered this objective, and wanted to try something more cognitively challenging on the exact same topic (i.e. **not** a next step in a workflow). Identify an objective they could work towards next.
> 2. Suppose a learner struggled to meet the specified objective. What might they be missing? Identify one more fundamental thing a learner needs to be able to do in order to be successful in meeting this objective.
>
> This exercise should take about 10 minutes.  
{: .challenge}

Some answers above may include words like "know" and "understand." Surely this is the objective of all teaching! However,
these terms are quite difficult to use when it comes time to *assess* whether a learner has met
that objective. They are also quite ambiguous with regard to the *level* of understanding to be achieved. Where you encounter these,
consider how they may be improved by making them specific to an outcome that is clearly achievable and readily assessed.

### Beware the Urge to Complicate
When experts teach, they are often eager to advance their learners to higher cognitive levels where challenges seem more interesting or valuable.
If the learning objectives in your lesson seem a bit dull, you can understand the appeal! And the goal is laudable. However, teaching is an incremental process,
and giving in to this urge can result in skipping steps (see "expert awareness gap" in previous episodes), leaving novice learners in a state of cognitive overload.  
'Higher order' tasks like synthesis or creation rely on more fundamental levels of understanding, and are therefore prone to failure when applied too soon.
Awareness of exactly what underlying knowledge is required at each step will help you to avoid asking too much. For more guidance on identifying the "level" of
a particular task, we recommend having a look at one of many excellent references on Bloom's Taxonomy.


## Prepare to Use Formative Assessments
When a learning objective has been met, everyone should know about it! You, as an Instructor, can be satisfied that your teaching has successfully translated
into learning. For learners, recognizing that they have successfully learned something is motivating and it also supports their ability to monitor their own
progress -- this awareness, or **metacognition**, is especially key to supporting continued learning beyond the classroom. However, not all lessons have
checkpoints built in where such progress is made clear. Where they do, they can pass unnoticed in the absence of focused recognition.

> ## Where are your Checkpoints?
>
> Have a look at your learning objective again and identify
> *where* in the lesson that objective should reasonably be achieved.
>
> This exercise should take about 5 minutes.
{: .challenge}

Now that you have identified one point where formative assessment may be useful, take a moment to consider how it might be used most
effectively.

> ## Assessment is for Everyone
> How might you apply formative assessment to:  
> a) verify that that achievement has been met by all and  
> b) make learners aware of their accomplishment?  
> Keep in mind that formative assessment can take many forms, including multiple
> choice questions, other exercises, spontaneous questions and calls for sticky
> notes. Write some notes or thoughts about this process in the Etherpad for
> discussion.
>
> This exercise and discussion should take about 10 minutes.
{: .challenge}


### How Frequent?
Instructors should use a formative assessment ideally every 5 minutes and
at least every 10-15 minutes
in order to make sure that the class is actually learning.
Since the average attention span is usually only this long,
formative assessments also help break up instructional time
and re-focus attention.
Formative assessments can also be used preemptively:
if you start a class with a question and everyone can answer it correctly,
then you can safely skip the part of the lecture
in which you were going to explain something that your learners already know.


> ## "Do You Understand?" is Ineffective as a Formative Assessment
>
> Learners are often reluctant to admit when they do not understand. Furthermore, self-assessments of skill in the absence of formative assessment are often inaccurate
> because of the [Dunning-Kruger effect][Dunning]:
> the less people know about a subject,
> the less accurate their estimate of their knowledge is. Therefore, if you ask a room full of people
> "Do you understand?" the result will invariably be a number of 'yes' responses (many of them inaccurate) which tend to drown out a
> variable amount of silence. Instead, a targeted formative assessment takes the inaccuracy and stress of self-judgement away and
> demonstrates to all whether the learners' level of understanding has
> met the instructor's goal.
{: .callout}


## Prepare to Cut
Collaborative maintenance of curriculum materials allows The Carpentries to maintain up-to-date workshops in a rapidly changing world.
We hope you will join in to support our Maintainers in overseeing this process, and even consider becoming a curriculum Maintainer yourself!
However, there is one down-side to collaborative upkeep: adding content is a much more fun way to contribute than proposing content to remove.
Every workshop moves at its own pace, but if you are following our recommendations to **go slowly** and pause for formative assessment, it is likely
that you will have to make cuts in what you plan to teach. Indeed, despite our best efforts at maintaining this curriculum, your Instructor Trainers
may well have had to make cuts to make space for great conversations or extra questions in this training!

There are many ways to make cuts in a workshop, and they can have variable knock-on effects to watch out for. A little advance planning goes a long way
to avoid making mistakes when you start cutting things 'on the fly.'
- **Keep breaks on time** even if your content is split awkwardly around them. Delaying breaks can demotivate your audience and disrupt plans they may
make around announced break times.
- **Watch out for dependencies** if you skip a step. It may not be a step they *needed to know* about, but it may generate or re-name a file that is used
in later episodes.
- **Leave time to wrap up your workshop** even if this means cutting even more content. We will talk about this more shortly.
- **Do not speed up** if you are running behind! All curricula are freely available so learners can visit content they have missed; this means there is very
little to be gained by "quickly covering" (but not actually teaching) content.
- **Communicate with your team** about what you plan to cut, or what you decided to leave out. Do not assume anyone will notice if you skip something. They may be
able to find a way to fit certain concepts in with later content if they know it has been missed.
- **Communicate with your learners** about where they can find skipped content and whether any help may be available to support their independent work. Cutting
content may make them feel anxious, but it will help for them to know how to follow up.


## Review the Instructor Notes
Many of The Carpentries lessons have
instructor's notes, with information
from instructors who have already taught the material. This can be a valuable
resource when preparing lessons, especially when teaching a lesson for the first time.  
The instructor notes are linked on each lesson page under the "Extras" pull down menu.
In addition, configuration problems and other
technical hurdles common across multiple lessons are detailed [in this community-developed page][Config]
along with suggested solutions. This link is built into each workshop website as well for easy access by learners and
during workshops. When you find new problems or solutions, please contribute!


## Review Prior Feedback
When is the best time to review your post-workshop survey responses and other feedback that you received during a workshop? We certainly recommend
taking time to do this after a workshop, while your memories are still fresh. However, we *also* recommend having a look again **before you teach your
next workshop**. This will help refresh your memory of all that went well (yay!) as well as challenges you faced and learners who struggled at certain points.
What will you keep the same, and what will you do differently?
Just a few moments of reflective practice with prior feedback will go a long way towards building your skill as a teacher and making each workshop you teach
better than the last.


> ## Repetition vs. Reflective Practice
>
> The idea that ten thousand hours of practice will make someone an expert in some field
> is widely known,
> but reality is much more complex.
> Practice is not doing the same thing over and over again:
> practice is doing similar but subtly different things,
> getting feedback,
> and then changing behavior in response to that feedback to get cumulatively better.
> Doing the same thing over and over again is much more likely to solidify bad habits than perfect performance.
> This is why we emphasize practice and feedback for learners at our workshops and for trainees in our
> Instructor Training program.
{: .callout}


## Connect With Your Team
Are you teaching with some of the same team-members you taught with previously? If so, this is a great time for *collaborative* feedback review! Depending on
your team's preferences, many of the independent preparation steps described here can be carried out collaboratively or at least in good company. In addition,
we will talk about how to prepare with your team to create a cohesive classroom experience in a later episode.


> ## Minute Cards Revisited
>
> Use your sticky notes to write minute cards
> as discussed [in part 1]({{ page.root }}/{% link _episodes/06-feedback.md %}#minute-cards).
{: .challenge}


[Wiggins]: https://www.worldcat.org/title/understanding-by-design/oclc/56491025
[Config]: https://github.com/carpentries/workshop-template/wiki/Configuration-Problems-and-Solutions
[Dunning]: https://en.wikipedia.org/wiki/Dunning%E2%80%93Kruger_effect
