---
title: "Working With Your Team"
block: "Building Teaching Skill"
teaching: 30
exercises: 40
questions:
- "What are the challenges of managing a heterogeneous classroom?"
- "What should we do if there is a Code of Conduct violation?"
- "What does it mean to be a co-Instructor?"
- "How does an instructional team prepare for a workshop?"
objectives:
- "Identify potential challenges of teaching learners with very different backgrounds and skill levels."
- "Locate resources to direct your response if someone at your workshop violates the Code of Conduct."
- "Identify workshop roles and responsibilities for your team."
- "Use The Carpentries workshop website template instructions to start creating a website."
keypoints:
- "Team work takes work, but allows you to share the load and build connections."
- "Working with a broad range of learners can be challenging, but there are many ways to keep a classroom happy and motivated."
- "The instructional team decides how to respond to Code-of-Conduct incidents during a workshop; all violations should be reported to The Carpentries Code of Conduct committee for follow-up."
---

## Never Teach Alone
One of the greatest strengths of Carpentries workshops compared with many other instructional settings is that workshops are prepared and executed
by more than one person. We ask that at least two Instructors teach in every workshop, and some workshops may have many more! During the workshop,
you should also have a crew of Helpers to answer questions individually, elevate common problems for general discussion, and make sure the pacing 
works for everyone.

The people who are planning and executing your workshop with you can really lighten the load! They are also there to
help if you find yourself in a sticky situation. However, from logistics planning to delicate problem solving, a little planning goes a long
way, and all co-Instructors should be in agreement about how they will support each other in engaging challenges. 
In this episode, we will discuss examples, strategies, and resources for handling challenges you may face in the classroom. We will
also take some time to discuss planning logistics, and (time permitting) everyone will have an opportunity to try out
our instructions for setting up a workshop website.

## The Instructional Team
A typical Carpentries workshop includes 3 roles; sometimes individuals may choose to play more than one role. Each workshop should have:
- A **Host** who organizes the workshop logistics
- Two or more **Instructors** who plan and execute workshop instruction
- **Helpers** who support learners during the workshop  

### Hosting
We will not spend a lot of time talking about the host role, because most of what they do is not directly related to teaching. However, this is 
a significant role in any workshop. A suggested checklist for this role is in [The Carpentries Handbook][host-checklist].

When Instructors self-organise a workshop, they sometimes find themselves playing the role of Host as well as Instructor.
We recommend avoiding this if possible, because hosting responsibilities will subtract from the time you have
to prepare and teach. 

If you cannot find someone else to bear full responsibility for the Host role, consider recruiting help for specific tasks. This may include 
involving helpers in advance of the workshop, or exploring institutional support for event logistics like registration, snack delivery, 
helper coordination, and emergency contact.

### Instructors: Co-teaching Models

*Co-teaching* describes any situation in which two teachers work
together in the same classroom. There are [many ways][worldcat-interactions] to do
this; we use the following methods most frequently:

- **Team teaching:** Both teachers deliver a single stream of content
  in tandem, taking turns the way that musicians taking solos would.

- **Teach and assist:** Teacher A teaches while Teacher B moves around
  the classroom to help learners.

"Teach and assist" is most common, in part because people are accustomed to teaching alone! However, 
"Team teaching" can be a fun way to lead together as well. Team teaching can be particularly helpful when two 
Instructors have very different strengths, creating a more balanced experience overall. This may also be worth 
considering for self-organised workshops if a co-Instructor has not yet been certified.

### Helpers

[Helpers][helpers] are usually recruited from a local community by the Host of a workshop. Helpers may be
involved prior to the day of the workshop, but often they simply show up. In most cases, helpers are expected to 
attend for the full workshop, but in some communities they may come and go during different segments.

Helpers can assist in a variety of ways. They may:
- help learners with setup and installation
- answer questions during exercises
- monitor the room to spot people who may need help (indicated by a sticky note or otherwise)
- monitor the shared notes and either answer questions there or remind the Instructor to do so during breaks

In order to help effectively, helpers need to be onboarded to the basic elements of Carpentries teaching
practices. [The helper checklist][helpers] includes a short list of "Teaching Rules" that may be shared with helpers. 
However, you will also want to make sure they are informed about key logistics and classroom practices.


### Carpentries Classroom Practices
Carpentries Instructors have many choices about how to teach. However, there are a few teaching practices that 
are expected in all Carpentries workshops. These include:

#### Starting with the Code of Conduct
  Looking for language to introduce the Code of Conduct during your workshop? The [summary view in The Carpentries Handbook][CoC-summary] is a great template.

#### Participatory Instruction & Hands-off Help
  Whether you are live coding, as we will discuss in more detail soon, or teaching other content, your learners should be actively 
  working along with you wherever possible. Similarly, when receiving assistance, learners should be doing the typing whenever possible.

> ## Learners Use Their Own Machines
> Learners tell us that it is important to them to leave the workshop
> with their own machine set up to do real work.  We therefore continue
> to teach on all three major platforms (Linux, Mac OS X, and Windows),
> even though it would be simpler to require learners to use just one.
>
> We have experimented with virtual machines (VMs) on learners'
> computers to reduce installation problems, but those introduce
> problems of their own: older or smaller machines simply are not fast
> enough, and learners often struggle to switch back and forth between
> two different sets of keyboard shortcuts for things like copying and
> pasting.
>
> Some instructors use [Virtual Private Servers][vps] (VPS) over [Secure Shell][ssh]
> (SSH) or web browser pages instead. This solves the installation
> issues, but makes us dependent on host institutions' WiFi (which can be
> unreliable), and has the issues mentioned above with things
> like keyboard shortcuts.
{: .callout}

#### Sticky Notes
 At in-person workshops, two different colors of paper sticky notes are given to each learner. These act as 'flags' that may be placed 
 on a laptop screen to indicate when a learner needs help or when they have completed a task and are ready to move on. 
 This is better than having people raise their hands because:  
*  it is more discreet (which means they are more likely to actually do it),
*  they can keep working while their flag is raised, and
*  the instructor can quickly see from the front of the room what state the class is in.  
 **Active and frequent requests** are most effective in getting learners to actually use these well (e.g. "please put up a blue sticky note if
 you completed the last step, and a yellow sticky note if you need help.").  
 In online workshops, Zoom has a green "✓" and red "x" under "reactions" that may be used in place of sticky notes.

> ## Accessibility of Sticky Notes
> Once upon a time, Carpentries workshops commonly used red and green sticky notes
> because of their common symbolism for "stop" and "go." However, we have learned 
> and grown! We strongly encourage you to get sticky notes in colors other than red and green (e.g. blue and yellow), 
> because learners, helpers, and Instructors with colorblindness may have difficulty
> distinguishing red from green. 
> Some Instructors have also had great fun with differently-shaped sticky notes (stars and squares, 
> thumbs up that can be turned into thumbs down stickies etc.).
{: .callout}

#### Formative Assessment  
 Calling for sticky notes is one kind of formative assessment! But it does not give you detailed information about how learners
 are progressing. 
 
#### Breaks (ideally with snacks)
 Two-day workshops often fit best in busy schedules, allowing an intensive burst of dedicated time and energy. However, "intensive" is 
 a key word -- two day workshops are intense! In addition to minding your pacing, it is important to schedule breaks, and to take them 
 on time. In addition to allowing vital rest and social time, this will also allow learners to attend to work and personal matters at predictable times.  
 At in-person workshops, beverages and snacks to suit a range of dietary needs are highly recommended. This may mean charging a 
 small fee for your workshop to cover the cost.
 
#### Feedback
 Using sticky cards as "minute cards" and creating time for Carpentries surveys are two essential components of a Carpentries workshop.
 Save your best feedback to look at on a tough day! 

## Sticky Situations 1: Learners at Many Levels

Carpentries workshops target novices, but participants from a variety of backgrounds and technical
skill levels will often sign up for workshops. Some may be novices in one technology (e.g. git),
but competent or even expert in another (e.g. R). As an Instructor,
you will need to be attentive to this range in your learners' prior skill level. 
"Meeting learners where they are" can seem like an impossible challenge under these circumstances!
But with a solid team approach you will be surprised at how many people can come
away feeling satisfied that their time was well spent.

> ## What Are the Challenges?
> What are some of the challenges you might expect when teaching learners with a broad range of expertise? Add your thoughts in the Etherpad.
>
> This discussion should take about 5 minutes.
{: .challenge}

Here are some strategies Carpentries
Instructors have generated to deal with this issue:

*   Be sure that workshop **advertisements communicate its level clearly**
    by describing not only the topics (e.g. plotting in R), but
    also the specific skills and tasks (i.e. the learning objectives).
    If advanced learners do sign up anyway (and they may!), this will be an informed choice.
*   Consider creating **"beginner" and "advanced" options** for exercises.
    Learners who finish the "beginner" exercise can then challenge themselves with a next step.
*   During class, **encourage learners to help others** nearby when they feel comfortable doing so.
    Teaching is a great way to level up learning (one of many reasons why Carpentries Instructors choose to teach!).
    Note that you will need an icebreaker before most learners will take this advice.
*   **Do not let advanced learners take over the conversation** during class, no matter how interesting it may be. This can alienate novices
    and consumes precious time. Advanced questions and comments can be politely reserved for breaks, addressed
    individually by helpers or the co-Instructor, or typed in the Etherpad for present or future follow-up.
*   The helpers and non-teaching co-Instructor(s)
    should **be vigilant for learners who are falling behind**
    and intervene early
    so that they do not become frustrated and give up. Frequent reminders
    to put up sticky notes for "ok" or "I'm stuck" will support your 
    team in targeting problems in time.

No class can possibly meet all individual training needs.
However, it is entirely possible for total beginners and advanced learners
to come away happy from the same workshop. Beginners may not yet feel competent,
but they may build a mental model of the domain and develop confidence that they *can*
learn these skills because they have successfully walked through them. Advanced
learners may enjoy picking up "tips and tricks" or having their own self-taught approaches
validated. They may also enjoy connecting with your workshop community, and might 
consider becoming Carpentries Instructors themselves! 

Dealing effectively with different skill levels does take some planning. However, with
appropriate advertising and team cohesion on priorities and strategies, your workshop
can be a worthwhile experience for everyone.


## Sticky Situations 2: Code of Conduct Violations

As discussed in an [earlier episode]({{ page.root }}{% link _episodes/09-eia.md %}),
the Carpentries uses a Code of Conduct as a tool to create an explicitly 
inclusive learning environment. This works well! But while the Code of Conduct may deter 
some kinds of bad behavior, any public event carries a risk that someone will say or do something 
that causes harm. 

A critical function of the Code of Conduct is to ensure that our community does not 
tolerate or encourage the persistence of harmful behaviors. In order for the code to work 
well, **incidents must be reported**. Note that it is not the responsibility of the reporter to 
determine whether a Code of Conduct violation has occurred; when in doubt, it is best to report 
an incident and allow the Code of Conduct Committee to make that determination.

Rarely, your instructional team may encounter a Code of Conduct violation during a workshop. In addition to reporting 
this incident, you will need to decide how and when to respond in the moment. While any individual may take it upon themselves 
to respond, team coordination can both lighten the load and improve the outcome. 
We encourage you to **discuss an approach to managing Code of Conduct violations with your instructional team in advance**. 

> ## Know Your Resources
> 1) Take 5 minutes to read through the Code of Conduct Incident Response Guidelines: <https://docs.carpentries.org/topic_folders/policies/incident-response.html>   
> 2) Discuss what you have read in small groups. As questions arise, you may wish to refer to our complete Code of Conduct section in The Carpentries Handbook: 
> <https://docs.carpentries.org/topic_folders/policies/index_coc.html> or to the Transparency Reports released by The Carpentries Code of Conduct Committee: <https://github.com/carpentries/executive-council-info/tree/master/code-of-conduct-transparency-reports>
> * What kinds of things could your instructional team agree upon in advance of your workshop? 
> * What questions do you have about CoC enforcement?  
> 
> 3) Write some notes in the Etherpad. 
>
> This discussion should take about 10 minutes.
{: .challenge}

Fortunately, Code of Conduct violations have been extremely rare in our community. We think that this is because emphasizing our values up front really
does make a difference. 

We hope that this preliminary introduction will help you work with your team to decide on a response in 
case you encounter a violation, and will support you in reporting incidents to prevent their recurrence. 
Thorough preparation to manage a difficult situation is useful for 
any leadership role, but is beyond the scope of this training event. 
Because this challenge is not unique to Instructors, The Carpentries is currently working
to address this unmet training need more broadly across our community through [development of a Code of Conduct Facilitator role][blog-coc-facilitators]. Follow
our communications channels to learn about additional opportunities for training in this area.

> ## Know your Local Laws and Policies
> While all Carpentries-branded workshops fall under The Carpentries Code of Conduct, they 
> are also subject to laws, policies, and guidelines specific to the institutions, states, and
> countries where they are hosted. In some cases, this may prevent people from being able to 
> promise confidentiality because they are legally required to report certain types of incidents
> (e.g. "mandatory reporters" in the USA).
{: .callout}

## Planning Together
Planning a workshop can be at least as much fun as teaching one. Why? Because this is the stage at which you get to connect 
with the amazing people on your instructional team! One reason why people love the workshop you are taking right now is because 
they get to meet other Carpentries trainees -- people with shared interests and enthusiasm for sharing technical skills. Yes,
there is work to do when planning a workshop! But there is much to be gained in sharing the process.

> ## Teaching Together - Nuts and Bolts
>
> With a partner, imagine that you are planning a workshop together. For this exercise, you may assume
> that your workshop has a separate, designated Host.
>
> - How would you prepare to teach a workshop together?
> - How would you coordinate with other members of your instructional team (e.g. Host, Helpers)?
> - What kinds of things will you do to support each other during the workshop? What won't you do?
> 
> Record some notes, and share your thoughts with the group. This exercise should take about 10 minutes.
>
>> ## Co-Instruction Suggestions
>>
>>
>>- Coordinate who is teaching what, sufficiently in advance that
>>  both instructors are confident in their preparation.
>>- Coordinate with your instructional team. Hosts will need information
>>  from you to advertise the workshop. Helpers will need to know what you
>>  expect from them. More communication is better, but it is also
>>  important to respect people's time.
>>
>>- If you have time to do some
>>  advance preparation together, try drawing a concept map together or
>>  teaching a short snippet of the lessons for each other.
>>
>>- Discuss in advance if you will provide feedback to each other
>>  and how to do so (see notes above).
>>
>>- If it will not cause cognitive overload for you (the instructors),
>>  work out a couple of hand signals to communicate.  "You are
>>  going too fast", "speak up", "that learner needs help", and, "It is
>>  time for a bathroom break" are all useful.
>>
>>- The person who is not teaching should not interrupt, offer
>>  corrections, elaborations, or amusing personal anecdotes, or do
>>  anything else to distract from what the person teaching at the time
>>  is doing or saying.  The one exception is that it is sometimes
>>  helpful to ask leading questions, particularly if the learners seem
>>  unsure of themselves.
>>
>>- For Carpentries workshops, a single instructor usually teaches for a
>>  half-day stretch (2-3 hours).  You can alternate more frequently, but
>>  each person should teach for at least 10-15 minutes at a stretch,
>>  since learners may be distracted by more frequent interleaving.
>>
>>- Each person should take a couple of minutes before they start
>>  teaching to see what their partner is going to teach after they are
>>  done.  This allows each instructor to set up their partner's material
>>  without covering it themselves.
>>
>>- Whenever possible, the person who is not teaching should stay engaged
>>  with the class.  Monitor the shared notes, keep an eye
>>  on the learners to see who is struggling, jot down some feedback to
>>  give your teaching partner at the next break - anything that
>>  contributes to the lesson is better than anything that does not.  It is
>>  easier for the other instructor to take a break to catch up on outside
>>  work (like email) if there are at least
>>  three instructors or sufficient helpers to make sure that the main
>>  instructor is supported.
> {: .solution}
{: .challenge}

In teaching as in life, shared misery is lessened and shared joy increased;
take a few minutes when the class is over to either
congratulate or commiserate with each other.  In that moment,
no-one will better understand how pleased you are at helping someone
understand how loops work, or how disappointed you are that you just
could not get software to install on that one learner's laptop, than
the person you just taught with.


### Setting up a Workshop Website

In addition to planning how the workshop will go, someone on your instructional team 
will be charged with creating a workshop website. This website helps your learners to
know what to expect. It also helps The Carpentries to keep track of your workshop and 
to credit everyone on your team.

The Carpentries maintains a template repository for these websites with step-by-step 
instructions for setting them up.

> ## Practice With The Carpentries Infrastructure
> 
> For this activity, your Trainer will put you in groups, but you may choose whether to work together or independently. 
> If you work independently, you can still use your group as a resource to ask questions as they emerge. 
>
> Go to the workshop template repository: <https://github.com/carpentries/workshop-template>
> 
> * If you have a GitHub account (or don't mind creating one) and are comfortable doing so, 
> follow the directions to begin creating a workshop website using your local location and today's date. 
> 
> * Alternatively, have a look at the video tutorial linked on the instructions page. With any time
> remaining, have a look at the websites for upcoming Carpentries workshops on our website: <https://carpentries.org/upcoming_workshops/>
> 
> * Add your questions and thoughts on this process to the Etherpad. If you created a workshop website,
> add the link there as well.
>
> This exercise should take about 15 minutes. 
>
> Note: Sometimes web browsers will cache the workshop webpage, so when
> you make changes in GitHub, they do not show up on the workshop webpage
> immediately.  Two ways to avoid this are to use a "private" or
> "incognito" mode in your web browser or by following these
> instructions to bypass your browser cache: <https://en.wikipedia.org/wiki/Wikipedia:Bypass_your_cache>.
{: .challenge}

You may also wish to create an Etherpad for your workshop
(or other Carpentries-related event).
When you point a browser to a url at
`https://pad.carpentries.org/workshop-slug`
(e.g., `https://pad.carpentries.org/2022-02-22-data-skills`
for the example above)
you will either arrive at an existing Etherpad by that name or a brand new
Etherpad with basic Carpentries information at the top.

Note that there are pros and cons to using Etherpad. Pads do occasionally
freeze or crash, so we recommend creating a backup copy. Otherwise, Etherpads persist 
indefinitely, so they may be used for further reference after a workshop. 

[blog-coc-facilitators]: https://carpentries.org/blog/2021/06/code-of-conduct-facilitators-module/
[worldcat-interactions]: https://www.worldcat.org/title/interactions-collaboration-skills-for-school-professionals/oclc/930364264
[host-checklist]: https://docs.carpentries.org/topic_folders/hosts_instructors/hosts_instructors_checklist.html#host-checklist
[helpers]: https://docs.carpentries.org/topic_folders/hosts_instructors/hosts_instructors_checklist.html#helper-checklist
[CoC-summary]: https://docs.carpentries.org/topic_folders/policies/code-of-conduct.html#code-of-conduct-summary-view
[vps]: https://en.wikipedia.org/wiki/Virtual_private_server
[ssh]: https://en.wikipedia.org/wiki/Secure_Shell
