---
layout: page
title: "Suggested Lessons for Teaching Demonstrations"
---

The list below shows lessons that have been reviewed for good and bad start points to use for a teaching demonstration. When selecting a lesson for a
teaching demonstration, trainees should review this list to ensure it is suitable.

Those who wish may also consult the detailed tables following the list to identify episodes marked "avoid" because they will not be asked to teach those episodes. However, we recommend
reviewing the full lesson regardless, as this will help provide context for other start points and is also good preparation for your eventual teaching
role!

Note that while a trainee can choose the lesson to teach from, the **Trainer leading the demo session will choose the specific episode at the time
of the demo session.** If you would like to use a lesson that is not listed here, you may contact the Instructor Trainer leading your teaching
demonstration or (if no one is listed for your session) email [instructor.training@carpentries.org](mailto:instructor.training@carpentries.org).

If the episode chosen by the trainer is very short and finishes in less than 5 minutes, the trainee can continue on to the next episode in that lesson. They are not
required to cover any specific amount of content within the 5 minute period.

* [Data Carpentry: Ecology](#dc-ecology)
  * [Data Cleaning with OpenRefine](https://datacarpentry.org/OpenRefine-ecology-lesson/)
  * [Data Analysis and Visualization in R](https://datacarpentry.org/R-ecology-lesson/)
  * [Data Management with SQL](http://www.datacarpentry.org/sql-ecology-lesson/)
  * [Data Analysis and Visualization in Python](http://www.datacarpentry.org/python-ecology-lesson/)
* [Data Carpentry: Genomics](#dc-genomics)
  * [Introduction to the Command Line](https://datacarpentry.org/shell-genomics/)
  * [Data Wrangling and Processing](https://datacarpentry.org/wrangling-genomics/)
  * [Introduction to Cloud Computing](https://datacarpentry.org/cloud-genomics/)
* [Data Carpentry: Social Sciences](#dc-socialsci)
  * [Data Organization in Spreadsheets](https://datacarpentry.org/spreadsheets-socialsci/)
  * [Data Cleaning with OpenRefine](http://www.datacarpentry.org/openrefine-socialsci/)
  * [Data Analysis and Visualization with R](http://www.datacarpentry.org/r-socialsci/)
* [Data Carpentry: Geospatial](#dc-geospatial)
  * [Introduction to R for Geospatial Data](https://datacarpentry.org/r-intro-geospatial/)
  * [Introduction to Raster and Vector Data with R](https://datacarpentry.org/r-raster-vector-geospatial/)
* [Data Carpentry: Astronomy](#dc-astro)
  * [Foundations of Astronomical Data Science](https://datacarpentry.org/astronomy-python/)
* [Data Carpentry: Image Processing](#dc-image)
  * [Image Processing with Python](https://datacarpentry.org/image-processing/)
* [Library Carpentry](#lc)
  * [Library Carpentry: The Shell Lesson](https://librarycarpentry.github.io/lc-shell/)
  * [Library Carpentry: OpenRefine](https://librarycarpentry.org/lc-open-refine/)
  * [Library Carpentry: Introduction to Git](https://librarycarpentry.org/lc-git/)
* [Software Carpentry](#swc)
  * [The Unix Shell](http://swcarpentry.github.io/shell-novice/)
  * [Version Control with Git](http://swcarpentry.github.io/git-novice/)
  * [Programming with Python](http://swcarpentry.github.io/python-novice-inflammation/)
  * [Plotting and Programming in Python](http://swcarpentry.github.io/python-novice-gapminder)
  * [R for Reproducible Scientific Analysis](http://swcarpentry.github.io/r-novice-gapminder/)
  * [Programming with R](http://swcarpentry.github.io/r-novice-inflammation/)
  * [Using Databases and SQL](http://swcarpentry.github.io/sql-novice-survey/)
  * [Automation and Make](http://swcarpentry.github.io/make-novice/)
  * [Version Control with Mercurial](http://swcarpentry.github.io/hg-novice/)
* [Lecciones en español](#espanol)
  * [La Terminal de Unix](http://swcarpentry.github.io/shell-novice-es/)
  * [Control de versiones con Git](http://swcarpentry.github.io/git-novice-es/)
  * [R para Análisis Científicos Reproducibles](http://swcarpentry.github.io/r-novice-gapminder-es/)
  * [Análisis y visualización de datos usando Python](http://www.datacarpentry.org/python-ecology-lesson-es/)


### <a id="dc-ecology"></a> Data Carpentry: Ecology

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Data Organization in Spreadsheets](https://datacarpentry.org/spreadsheet-ecology-lesson/) |  any episode | none ||
| [Data Cleaning with OpenRefine](https://datacarpentry.org/OpenRefine-ecology-lesson/) |  [Exploring Data with OpenRefine](https://datacarpentry.org/OpenRefine-ecology-lesson/02-exploring-data/index.html) | any other episode | The intro episode has no live coding. <br/> Other episodes have dependencies. |
| [Data Analysis and Visualization in R](https://datacarpentry.org/R-ecology-lesson/) |  * Introduction to R<br/>* Starting with Data | * [Before We Start](http://www.datacarpentry.org/R-ecology-lesson/00-before-we-start.html)<br/> * [Manipulating Data](https://datacarpentry.org/R-ecology-lesson/03-dplyr.html)<br/> * [Data Visualization with ggplot2](https://datacarpentry.org/R-ecology-lesson/04-visualization-ggplot2.html)<br/> * [SQL Databases and R](https://datacarpentry.org/R-ecology-lesson/05-r-and-databases.html)<br/>| [Before We Start](http://www.datacarpentry.org/R-ecology-lesson/00-before-we-start.html) has no live coding. <br/> Manipulating Data and [Data Visualization with ggplot2](https://datacarpentry.org/R-ecology-lesson/04-visualization-ggplot2.html) have dependencies. <br/> SQL and `RSQLite` are taught less frequently. |
| [Data Management with SQL](http://www.datacarpentry.org/sql-ecology-lesson/) | any other episode | [Databases using SQL](http://www.datacarpentry.org/sql-ecology-lesson/00-sql-introduction/) | Live coding starts in the middle of the episode to avoid. |
| [Data Analysis and Visualization in Python](http://www.datacarpentry.org/python-ecology-lesson/) |  * [Short Introduction to Programming](https://datacarpentry.org/python-ecology-lesson/01-short-introduction-to-Python/)<br/> * [Starting with Data](https://datacarpentry.org/python-ecology-lesson/02-starting-with-data/)<br/> * [Indexing, Slicing, and Subsetting](https://datacarpentry.org/python-ecology-lesson/03-index-slice-subset/)<br/> * [Data Types and Formats](https://datacarpentry.org/python-ecology-lesson/04-data-types-and-format/)<br/> * [Combining DataFrames with Pandas](https://datacarpentry.org/python-ecology-lesson/05-merging-data/)<br/> * [Data Workflows and Automation](https://datacarpentry.org/python-ecology-lesson/06-loops-and-functions/) | any other episode | [Before we Start](https://datacarpentry.org/python-ecology-lesson/00-before-we-start/) has no live coding. <br/> Later episodes have dependencies. |

### <a id="dc-genomics"></a>Data Carpentry: Genomics

If you are an instructor in training and wish to use lessons from Data Carpentry’s Genomics curriculum for your teaching demo, please read [these instructions](https://datacarpentry.org/genomics-workshop/teaching_demos/index.html) to be sure you are prepared. You must follow these steps before your teaching demo, or you will be asked to reschedule.

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Project Organization and Management for Genomics](https://datacarpentry.org/organization-genomics/) | none | all episodes | Discussion based. No live coding. |
| [Introduction to the Command Line](https://datacarpentry.org/shell-genomics/) |  all episodes | none | If using [Introducing the Shell](https://datacarpentry.org/shell-genomics/01-introduction/) begin with `cd shell_data` |
| [Data Wrangling and Processing](https://datacarpentry.org/wrangling-genomics/) |  * [Assessing Read Quality](https://datacarpentry.org/wrangling-genomics/02-quality-control/index.html) <br/> * [Trimming and Filtering](https://datacarpentry.org/wrangling-genomics/03-trimming/index.html) <br/> * [Automating a Variant Calling Workflow](https://datacarpentry.org/wrangling-genomics/05-automation/index.html)  | any other episode |  For [Assessing Read Quality](https://datacarpentry.org/wrangling-genomics/02-quality-control/index.html) begin with `gunzip SRR2584863_1.fastq.gz`  |
| [Introduction to Cloud Computing](https://datacarpentry.org/cloud-genomics/) |  * [Logging onto  the Cloud](https://datacarpentry.org/cloud-genomics/02-logging-onto-cloud/index.html)  <br/> * [Fine tuning your Cloud Setup](https://datacarpentry.org/cloud-genomics/03-verifying-instance/index.html) | any other episode | Have trainees teach the version “AWS_UNIX”.  |
| [Data Analysis and Visualization in R](https://datacarpentry.org/genomics-r-intro/) | none  | all episodes | This lesson is not yet stable. |

### <a id="dc-socialsci"></a>Data Carpentry: Social Sciences

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Data Organization in Spreadsheets](https://datacarpentry.org/spreadsheets-socialsci/) | * [Dates as Data](https://datacarpentry.org/spreadsheets-socialsci/03-dates-as-data/index.html)<br/> * [Quality Assurance](https://datacarpentry.org/spreadsheets-socialsci/04-quality-assurance/index.html) | * [Introduction](https://datacarpentry.org/spreadsheets-socialsci/00-intro/index.html)<br/> * [Formatting Data Tables in Spreadsheets](https://datacarpentry.org/spreadsheets-socialsci/01-format-data/index.html)<br/> * [Formatting problems](https://datacarpentry.org/spreadsheets-socialsci/02-common-mistakes/index.html)<br/> * [Exporting data](https://datacarpentry.org/spreadsheets-socialsci/05-exporting-data/index.html) | Episodes listed to avoid have no live coding. |
| [Data Cleaning with OpenRefine](http://www.datacarpentry.org/openrefine-socialsci/) |  [Working with OpenRefine](http://www.datacarpentry.org/openrefine-socialsci/02-working-with-openrefine/) | any other episode | [Introduction](https://datacarpentry.org/openrefine-socialsci/01-introduction/) has no live coding. <br/> Later episodes have dependencies. |
| [Data Analysis and Visualization with R](http://www.datacarpentry.org/r-socialsci/) | any other episode | * [Before We Start](http://www.datacarpentry.org/r-socialsci/00-intro/)<br/> * [Data Visualization with ggplot2](https://datacarpentry.org/r-socialsci/04-ggplot2/)|  [Before We Start](http://www.datacarpentry.org/r-socialsci/00-intro/) has no live coding. <br/> [Data Visualization with ggplot2](https://datacarpentry.org/r-socialsci/04-ggplot2/) has dependencies. |

### <a id="dc-geospatial"></a>Data Carpentry: Geospatial

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Project Organization and Management](https://datacarpentry.org/organization-geospatial/) | none | all episodes |  This lesson has no live coding. <br/> Do not use for teaching demos. |
| [Introduction to R for Geospatial Data](https://datacarpentry.org/r-intro-geospatial/) |  any episode | none | |
| [Introduction to Raster and Vector Data with R](https://datacarpentry.org/r-raster-vector-geospatial/) | * [Intro to Raster Data in R](https://datacarpentry.org/r-raster-vector-geospatial/01-raster-structure/)<br/> * [Reproject Raster Data in R](https://datacarpentry.org/r-raster-vector-geospatial/03-raster-reproject-in-r/)<br/> * [Work with Multi-Band Rasters in R](https://datacarpentry.org/r-raster-vector-geospatial/05-raster-multi-band-in-r/)<br/> * [Open and Plot Shapefiles in R](https://datacarpentry.org/r-raster-vector-geospatial/06-vector-open-shapefile-in-r/)<br/> * [Handling Spatial Projection & CRS in R](https://datacarpentry.org/r-raster-vector-geospatial/09-vector-when-data-dont-line-up-crs/)<br/> * [Convert from a .csv to a Shapefile in R](https://datacarpentry.org/r-raster-vector-geospatial/10-vector-csv-to-shapefile-in-r/)<br/> * [Raster Time Series Data in R](https://datacarpentry.org/r-raster-vector-geospatial/12-time-series-raster/) | any other episode | Many episodes rely on data from previous episodes. <br/> Trainees may need extra time to set up their environment. |


### <a id="dc-astro"></a> Data Carpentry: Astronomy

| Lesson  | (For Trainers)  Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Foundations of Astronomical Data Science](https://datacarpentry.org/astronomy-python/) | * [Basic Queries](https://datacarpentry.org/astronomy-python/01-query/index.html) <br/> * [Coordinate Transformations](https://datacarpentry.org/astronomy-python/02-coords/index.html) | any other episode |  Later episodes have dependencies. <br/> For [Basic Queries](https://datacarpentry.org/astronomy-python/01-query/index.html) skip the episode introduction, _Query Language_, and _Using Jupyter_ sections, and begin with [_Connecting to Gaia_](https://datacarpentry.org/astronomy-python/01-query/index.html#connecting-to-gaia) (`from astroquery.gaia import Gaia`)  |

### <a id="dc-image"></a> Data Carpentry: Image Processing

| Lesson  | (For Trainers)  Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Image Processing with Python](https://datacarpentry.org/image-processing/) | * [Working with skimage](https://datacarpentry.org/image-processing/03-skimage-images/index.html) <br/> * [Drawing and Bitwise Operations](https://datacarpentry.org/image-processing/04-drawing/index.html) <br/> * [Creating Histograms](https://datacarpentry.org/image-processing/05-creating-histograms/index.html)<br/> * [Thresholding](https://datacarpentry.org/image-processing/07-thresholding/index.html) | any other episode |  Other episodes begin with too much explanatory content for a teaching demo. <br/> This lesson is designed to be taught with a [JupyterLab](https://jupyter.org/) environment. |


### <a id="lc"></a>Library Carpentry

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
| [Library Carpentry: The Shell Lesson](https://librarycarpentry.github.io/lc-shell/) | * [ Navigating the filesystem](https://librarycarpentry.github.io/lc-shell/02-navigating-the-filesystem/index.html)<br/> * [Working with files and directories](https://librarycarpentry.github.io/lc-shell/03-working-with-files-and-folders/index.html)<br/> * [Automating the tedious with loops](https://librarycarpentry.github.io/lc-shell/04-loops/index.html)<br/> * [Counting and mining with the shell](https://librarycarpentry.github.io/lc-shell/05-counting-mining/index.html)<br/> * [Working with free text](https://librarycarpentry.github.io/lc-shell/06-free-text/index.html) | [What is the shell?](https://librarycarpentry.github.io/lc-shell/01-intro-shell/)  |  [What is the shell?](https://librarycarpentry.github.io/lc-shell/01-intro-shell/) has no live coding. |
| [Library Carpentry: OpenRefine](https://librarycarpentry.org/lc-open-refine/) | * [Importing data into OpenRefine](https://librarycarpentry.org/lc-open-refine/02-importing-data/index.html) | any other episode | [Introduction to OpenRefine](https://librarycarpentry.org/lc-open-refine/01-introduction/index.html) has no live coding. <br/> Later episodes have dependencies. |
| [Library Carpentry: Introduction to Working with Data (Regular Expressions)](https://librarycarpentry.org/lc-data-intro/) | No episodes | Avoid all episodes. | Episodes are built through exercises without an obvious live-coding component that is not explaining the solution to the exercise. |
| [Library Carpentry: Introduction to Git](https://librarycarpentry.org/lc-git/) | * [Getting started with Git](https://librarycarpentry.org/lc-git/02-getting-started/index.html) | any other episode | [What is Git/GitHub?](https://librarycarpentry.org/lc-git/01-what-is-git/index.html) has no live coding. <br/> Later episodes have dependencies. |
| [Library Carpentry: SQL](https://librarycarpentry.org/lc-sql/) | * [Selecting and Sorting Data](https://librarycarpentry.org/lc-sql/02-selecting-sorting-data/index.html)<br/> * [Filtering](https://librarycarpentry.org/lc-sql/03-filtering/index.html)<br/> * [Ordering and Commenting](https://librarycarpentry.org/lc-sql/04-ordering-commenting/index.html)<br/> * [Aggregating and Calculating Values](https://librarycarpentry.org/lc-sql/05-aggregating-calculating/index.html)<br/> * [Joins and aliases](https://librarycarpentry.org/lc-sql/06-joins-aliases/index.html)<br/> * [Saving queries](https://librarycarpentry.org/lc-sql/07-saving-queries/index.html)<br/> * [Creating tables and modifying data](https://librarycarpentry.org/lc-sql/09-create/index.html) | * [Database design](https://librarycarpentry.org/lc-sql/08-database-design/index.html)<br/> * [Other database tools](https://librarycarpentry.org/lc-sql/10-other-tools/index.html)<br/> * [Extra-challenges](https://librarycarpentry.org/lc-sql/11-extra-challenges/index.html)<br/> * [Good style](https://librarycarpentry.org/lc-sql/Bonus_GoodStyle/index.html) |

### <a id="swc"></a>Software Carpentry

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |---------- |---------- |
|  [The Unix Shell](http://swcarpentry.github.io/shell-novice/) | any other episode | [Introducing the Shell](https://swcarpentry.github.io/shell-novice/01-intro) |  [Introducing the Shell](https://swcarpentry.github.io/shell-novice/01-intro) has no live coding. |
|  [Version Control with Git](http://swcarpentry.github.io/git-novice/) |  * [Setting up Git](http://swcarpentry.github.io/git-novice/02-setup)<br/> * [Creating a Repository](http://swcarpentry.github.io/git-novice/03-create)<br/> * [Tracking Changes](http://swcarpentry.github.io/git-novice/04-changes)| any other episode | [Automated Version Control](http://swcarpentry.github.io/git-novice/01-basics) has no live coding. <br/> Later episodes have dependencies. |
| [Programming with Python](http://swcarpentry.github.io/python-novice-inflammation/) | any other episode | [Debugging](https://swcarpentry.github.io/python-novice-inflammation/09-debugging/) |  [Debugging](https://swcarpentry.github.io/python-novice-inflammation/09-debugging/) has no live coding. |
| [Plotting and Programming in Python](http://swcarpentry.github.io/python-novice-gapminder) | any other episode | [Variable Scope](http://swcarpentry.github.io/python-novice-gapminder/15-scope/index.html) <br/> [Programming Style](http://swcarpentry.github.io/python-novice-gapminder/18-style/index.html)  <br/>  | [Variable Scope](http://swcarpentry.github.io/python-novice-gapminder/15-scope/index.html) is very short and more conceptual/exercises than live coding <br/> [Programming Style](http://swcarpentry.github.io/python-novice-gapminder/18-style/index.html) is brief, and mostly concepts/excercises more than live coding. <br/>   |
| [R for Reproducible Scientific Analysis](http://swcarpentry.github.io/r-novice-gapminder/) | any other episode | [Splitting and Combining Data Frames with plyr](http://swcarpentry.github.io/r-novice-gapminder/12-plyr/index.html) <br> [Writing Good Software](https://swcarpentry.github.io/r-novice-gapminder/16-wrap-up/)  | The plyr package is largely deprecated. <br> [Writing Good Software](https://swcarpentry.github.io/r-novice-gapminder/16-wrap-up/) has no live coding. |
| [Programming with R](http://swcarpentry.github.io/r-novice-inflammation/) | * [Analyzing Multiple Data Sets](http://swcarpentry.github.io/r-novice-inflammation/03-loops-R/index.html) <br/> *  [Loops in R](http://swcarpentry.github.io/r-novice-inflammation/15-supp-loops-in-depth/index.html) <br/> * [Making Choices](http://swcarpentry.github.io/r-novice-inflammation/04-cond/index.html)  | * [Creating Functions](http://swcarpentry.github.io/r-novice-inflammation/02-func-R/index.html) <br/> *  [Best Practices for Writing R Code](http://swcarpentry.github.io/r-novice-inflammation/06-best-practices-R/index.html) <br/> *  [Reading and Writing CSV Files](http://swcarpentry.github.io/r-novice-inflammation/11-supp-read-write-csv/index.html) |  The episodes to avoid have dependencies. |
| [Using Databases and SQL](http://swcarpentry.github.io/sql-novice-survey/) | any other episode | [Data Hygiene](https://swcarpentry.github.io/sql-novice-survey/08-hygiene/) |  [Data Hygiene](https://swcarpentry.github.io/sql-novice-survey/08-hygiene/) has no live coding. |
| [Automation and Make](http://swcarpentry.github.io/make-novice/) |  * [Introduction](http://swcarpentry.github.io/make-novice/01-intro)<br/> *  [Makefiles](http://swcarpentry.github.io/make-novice/02-makefiles) | any other episode | Later episodes have dependencies. |
| [Version Control with Mercurial](http://swcarpentry.github.io/hg-novice/) |  * [Configuring Mercurial](http://swcarpentry.github.io/hg-novice/02-configuration/)<br/> * [Creating a Repository](http://swcarpentry.github.io/hg-novice/03-create-repo/)<br/> * [Tracking Changes to Files](http://swcarpentry.github.io/hg-novice/04-tracking/) | any other episode | [Automated Version Control](http://swcarpentry.github.io/hg-novice/01-basics/) has no live coding. <br/> Later episodes have dependencies. |

### <a id="espanol"></a>Lecciones en español

|  Lesson   | (For Trainers) Good Starting Points | (For Trainers) Avoid | Notes
|---------- |---------- |---------- |---------- |
|  [La Terminal de Unix](http://swcarpentry.github.io/shell-novice-es/) | any other episode | [Introducción a la Terminal](https://swcarpentry.github.io/shell-novice-es/01-intro) |  [Introducción a la Terminal](https://swcarpentry.github.io/shell-novice-es/01-intro) no tiene programando en vivo. |
|  [Control de versiones con Git](http://swcarpentry.github.io/git-novice-es/) |  * [Configurando Git](http://swcarpentry.github.io/git-novice-es/02-setup)<br/> * [Creando un repositorio](http://swcarpentry.github.io/git-novice-es/03-create)<br/> * [Rastreando Cambios](http://swcarpentry.github.io/git-novice-es/04-changes)| cualquier otro episodio | [Control Automatizado de Versiones](http://swcarpentry.github.io/git-novice-es/01-basics) no tiene programando en vivo. <br/> Los episodios posteriores tienen dependencias. |
| [R para Análisis Científicos Reproducibles](http://swcarpentry.github.io/r-novice-gapminder-es/) | cualquier otro episodio | [Escribiendo buen software](https://swcarpentry.github.io/r-novice-gapminder-es/16-wrap-up/) | [Escribiendo buen software](https://swcarpentry.github.io/r-novice-gapminder-es/16-wrap-up/) no tiene programando en vivo. |
| [Análisis y visualización de datos usando Python](http://www.datacarpentry.org/python-ecology-lesson-es/) |  * [Breve introducción a la Programación en Python](https://datacarpentry.org/python-ecology-lesson-es/01-short-introduction-to-Python/)<br/> * [Comenzando con datos](https://datacarpentry.org/python-ecology-lesson-es/02-starting-with-data/)<br/> * [Indexación, segmentación y creación de subconjuntos](https://datacarpentry.org/python-ecology-lesson-es/03-index-slice-subset/)<br/> * [Data Types and Formats](https://datacarpentry.org/python-ecology-lesson-es/04-data-types-and-format/)<br/> * [Combinando DataFrames con Pandas](https://datacarpentry.org/python-ecology-lesson-es/05-merging-data/)<br/> * [Flujos de trabajo y automatización](https://datacarpentry.org/python-ecology-lesson-es/06-loops-and-functions/) | cualquier otro episodio | [Antes de comenzar](https://datacarpentry.org/python-ecology-lesson-es/00-before-we-start/) has no live coding. <br/> Los episodios posteriores tienen dependencias. |
