---
layout: page
title: "Glossary"
---

*   **Accessibility**: 
    Equal access to learning opportunities regardless of learners' physical abilities or other attributes.

*   **Authentic Task**:
    A task which contains important elements of things that learners would
    do in real life (i.e. non-classroom situations).  To be authentic, a task should
    require learners to construct their own answers rather than choose
    among provided answers, and to work with the same tools and data
    they would use in real life.

*   **Chunking**:
    The act of grouping related concepts together so that they can be
    stored and processed as a single unit.

*   **Cognitive Load**:
    [Cognitive load][wikipedia-cognitive-load] is the amount of mental
    effort required to solve a problem.  Cognitive load theory divides
    this effort into *intrinsic*, *extraneous*, and *germane*, and holds
    that people learn faster and better when extraneous load is reduced.

*   **Community of Practice**:
    A self-perpetuating group of people who share and develop a craft or
    occupation, such as knitters, musicians, or programmers.

*   **Competent Practitioner**:
    Someone who can do normal tasks with normal effort under normal
    circumstances.
    <br>
    See also *novice* and *expert*.

*   **Concept Map**:
    A picture of a mental model in which concepts are nodes in a graph
    and relationships are (labelled) arcs.

*   **Deliberate Practice**:
    The act of observing performance of a task while doing it in order to
    improve ability.

*   **Diagnostic Power**:
    The degree to which a wrong answer to a question or exercise tells the
    instructor what misconceptions a particular learner has.

*   **Educational Psychology**:
    The study of how people learn.
    <br>

*   **Effort-based Praise**: 
    Providing positive feedback to learners that recognizes and rewards their hard work.
    <br>
    See also *improvement-based praise* and *performance-based praise*.

*   **Error Framing**: Presenting errors as an integral part of the learning process and using them as teaching opportunities.

*   **Expert**:
    Someone who can diagnose and handle unusual situations, knows when the
    usual rules do not apply, and tends to recognize solutions rather than
    reasoning to them.
    <br>
    See also *competent practitioner* and *novice*.

*   **Expert Awareness Gap**:
    The inability of experts to empathize with novices who are
    encountering concepts or practices for the first time. 
    Often referred to as expert blind spot in the literature. 

*   **Faded Example**:
    A series of examples in which a steadily increasing number of key
    steps are blanked out.
    <br>
    See also *scaffolding*.

*   **Fixed Mindset**:
    The belief that an ability is innate, and that failure is due to a
    lack of some necessary attribute.
    <br>
    See also *growth mindset*.

*   **Fluid Representation**:
    The ability to move quickly between different models of a problem.

*   **Formative Assessment**:
    Assessment that takes place during a lesson in order to give both the
    learner and the instructor feedback on actual understanding.
    <br>
    See also *summative assessment*.

*   **Growth Mindset**:
    The belief that ability comes with practice.
    <br>
    See also *fixed mindset*.

*   **Impostor Syndrome**:
    A feeling of insecurity about one's accomplishments that manifests as
    a fear of being exposed as a fraud.

*   **Improvement-based Praise**: 
    Providing positive feedback to learners that recognizes and rewards improvements they have made.
    <br>
    See also *effort-based praise* and *performance-based praise*.

*   **Inclusivity**:
    Working actively to include people with diverse backgrounds and needs.

*   **Inquiry-Based Learning**:
    The practice of allowing learners to ask their own questions, set
    their own goals, and find their own path through a subject.

*   **Lateral Knowledge Transfer**:
    The "accidental" transfer of knowledge that occurs when an instructor
    is teaching one thing, and the learner picks up another.

*   **Learner Profile**:
    A brief description of a typical target learner for a lesson that
    includes their general background, what they already know, what they
    want to do, how the lesson will help them, and any special needs they
    might have.

*   **Learning Objective**:
    What a lesson is trying to achieve.

*   **Lesson Study**: 
    The process in which instructors collaboratively plan lessons,
    observe each other's teaching, and discuss teaching experiences
    in order to learn from each other.

*   **Live Coding**:
    The act of teaching programming by writing software in front of
    learners as the lesson progresses.

*   **Long-Term Memory**:
    The part of memory that stores information for long periods of time.
    Long-term memory is very large, but slow.
    <br>
    See also *short-term memory*.

*   **Mental Model**:
    A representation of a person's knowledge and thought processes about a topic or domain.

*   **Minute Cards**:
    A feedback technique in which learners spend a minute writing one
    positive thing about a lesson (e.g., one thing they have learned) and
    one negative thing (e.g., a question that still hasn't been answered).

*   **Novice**:
    Someone who has not yet built a usable mental model of a domain.
    <br>
    See also *competent practitioner* and *expert*.

*   **One-Up, One-Down**: 
    A feedback technique in which learners take turns giving positive and negative feedback without repeating anything that has been said before.

*   **Participatory Live Coding**
	A style of teaching where the instructor [live codes][wikipedia-live-coding] 		
	and the learners "code along".

*   **Performance-based Praise**:
    Providing positive feedback to learners that focuses on whether they have attained the correct answer.
    <br>
    See also *effort-based praise* and *performance-based praise*.

*   **Perseverance**: 
    The trait of persisting in the face of difficulty.

*   **Persistent Memory**:
    see *long-term memory*.

*   **Plausible Distractor**:
    A wrong answer to a multiple-choice question that will seem to some students to be correct due to a misconception they hold.
    <br>
    See also *diagnostic power*.

*   **Reflective Practice**:
    see *deliberate practice*.

*   **Scaffolding**:
    Extra material provided to early-stage learners to help them solve problems.

*   **Short-Term Memory**:
    The part of memory that briefly stores information that can be
    directly accessed by consciousness.

*   **Stereotype Threat**:
    A situation in which people feel that they are at risk of being held
    to stereotypes of their social group.

*   **Summative Assessment**:
    Assessment that takes place at the end of a lesson to tell whether the
    desired learning has taken place.

*   **Working Memory**:
    see *short-term memory*.

[wikipedia-cognitive-load]: https://en.wikipedia.org/wiki/Cognitive_load
[wikipedia-live-coding]: https://en.wikipedia.org/wiki/Live_coding 
