---
layout: page
title: "Trainer Notes"
---

Table of Contents

* [I. Information For and About Instructor Trainers](#more-info)
* [II. Running an Instructor Training Event (General)](#general)
* [III. Online vs In Person Training Events](#online-inperson)
* [IV. Using Zoom  for Online Trainings](#zoom)
* [V. Curriculum Teaching Tips](#curriculum)


## I. Information For and About Instructor Trainers

<a name="more-info"></a>

Details about the Instructor Trainer role including the application process, duties, meetings, and administrative instructions are now housed in the [Carpentries Handbook][handbook]. To the extent that information in those instructions is directly pertinent to teaching an Instructor Training workshop, some items may be duplicated here. All other information previously housed on this page may now be found in the handbook. [Instructions on running a Demo session][demos] are also provided in the Trainer Guide.

## II. Running an Instructor Training Event (General)

<a name="general"></a>

### Four Weeks before the Event
-  Contact your co-Trainer(s) to plan how you will co-teach.  Suggested discussion questions include:
    - What are some useful tips and tricks to organize yourself, pace yourself, share resources, etc. while teaching?
    - How do you ensure that all trainees stay engaged and participate?
    - How can Trainers help each other (at times when we are not the active Trainer)? How should we communicate with each other during the training?
    - How can we address trainee challenges? These may include internet connectivity problems, distractions caused by working from home, etc.
-  Create an event Etherpad (using the [Etherpad template][etherpad-template]) or Google Doc (there is now a [template](https://docs.google.com/document/d/1P_w1rgdVk4SpXvILSS-ZKz8Ujqklfujpc_zHf8D-G1A/edit?usp=sharing) for that, too) and a workshop website (using the [training template][training-template]). *Be sure to check the event Etherpad or Google Doc against the curriculum as you prepare to teach, as these may not be reliably updated with curriculum changes.*
-  Send Etherpad/Google Doc and website links to training@carpentries.org.  
-  Consider forking the Instructor Training curriculum and doing all of your preparation work based on your fork so that any changes do not impact your preparation.

### One Week before the Event    
-  Plan logistics with co-Trainer(s)
-  Review (or set aside time closer to the event to review) the pre-assessment survey results for your workshop
-  If teaching remotely:
    -  Test videoconferencing set up with co-Trainer(s) using login credentials provided.   
    -  Decide with co-Trainer(s) whether all Trainers should be present for the full event or if you will log on during your scheduled teaching times only.  
    -  Make a copy of the [Virtual Minute Cards template][minute-cards-template] and personalize for your event. To make a copy, click on the three dots at the top right and select "Make a copy" on the drop-down. ("Add to My Drive" will **not** create a new copy of the form, but will instead add a shortcut to the original template from your Google Drive.)
-  If teaching in person:
    - Confirm with your host that breakout rooms are available or make an alternate plan
    - Create a plan for printing handouts & determine who will bring sticky notes
    - Make sure you are prepared for the audiovisual setup in your room with the correct dongles/connectors etc.
    - Check on availability/timing of breaks, lunch, or any other details that matter to you

### During the event
-  Take attendance.  
-  Remind member trainees to fill out application (Open Training applicants have already done this).   
-  Remind trainees to sign up for demo, discussion (links in [checkout checklist][checkout-checklist]).  
-  Monitor the Etherpad / Google Doc for questions and responses to exercises.  
-  If teaching remotely: Ensure that you are logged into the Zoom room with the host key so that you can mute participants and create breakout rooms as needed.
-  If teaching remotely: Turn off video during long exercises and breaks and disconnect during lunch (note: you may need to re-log in with the host key if returning after disconnecting).  

### Immediately after the event
-  Send a list of those who completed the training to checkout@carpentries.   
-  Send an email to trainees thanking them for participating and linking to [checkout checklist][checkout-checklist]. See template [here][post-template].  
-  Review survey results and prepare to discuss at upcoming [Trainers discussion meeting][trainer-pad].  
-  File any relevant issues or PRs to the [instructor training repo][training-repo].  

### Long-term after the event
-  Join a [Trainer discussion meeting][trainer-pad] to discuss how your event went.   

### Using Slides

Whether or not slides should be used during instructor training
is a subject of [frequent discussion][great-slide-issue].

The main **advantage** is that slides provide a visual aid when explaining
complex concepts or when presenting learning objectives and challenges.
The most notable **disadvantage** is that it can give the false impression
that it is okay to use slides rather than live coding in SWC/DC/LC workshops
For online instructor training events, there are two additional risks:
the slides may fail to advance using Zoom's screen share feature and
you risk losing the audience's attention because your face is less prominent.

If you chose to use slides in your workshop,
this [Google Drive folder][slides-folder] contains slides with diagrams, cartoons, and text that trainers have used past workshops. Feel free to reuse the existing materials or add your own slides.

### Using Etherpad

Each workshop will have an Etherpad.
You can use the [Instructor Training Etherpad template](https://pad.carpentries.org/ttt-template)
to quickly copy and paste challenges or useful information into your Etherpad.

Given the central role that Etherpad plays is running Carpentry workshops,
you may want to take a minute to explain [how to create a pad](https://pad.carpentries.org/),
what pads can be used for, and how long pads stick around. You may also want to point attendees to the ["pad of pads"](https://pad.carpentries.org/pad-of-pads).

### General Preparation

- Have water and cough drops nearby.
- Decide ahead of time if you will be using google docs or an Etherpad.
- Most people like or enjoy this training.
- There is no such thing as "too much coffee" or "too many donuts"

### Using Helpers/Co-Instructors

If you have a helper for the training, or want to involve your co-instructor more,
here are some ways where it is easy to do so without much prep:
* give an example of a mental model in "Building Skill with Practice"
* tell a motivational/demotivational story in "Motivation and Demotivation"
* help collect 1-up, 1-down feedback by either writing or directing the participants
* find + talk about a good (or bad) learning objective in "Preparing to Teach"
* have this person monitor the chat (if online) and answer questions, catch "hands"

### Episode order

Experience has shown that the current order of episodes works quite well.
If you are a new Trainer, we recommend following the official order, however,
the material is flexible enough to allow small shifts in episode order.
If you are an experienced Trainer and you would like to re-arrange the schedule,
make sure to communicate with your trainees and co-Trainers!

## III. Online vs In Person Training Events

<a name="online-inperson"></a>

### In-person trainings
- When watching videos, project them to the whole group.   
- Assign (or let participants select) physical breakout groups.  
- Use physical sticky notes to get minute card feedback at lunch breaks and end of each day.  

### Online trainings (a few small groups)
- When watching videos, have one Trainer do a screenshare with their audio on or have one person in each group play the video for the participants at their site.  
- Assign (or let participants select) physical breakout groups.  
- Use the [virtual minute card][minute-cards-template] form to get feedback at lunch breaks and end of each day.  
- Have participants do all small-group exercises with participants at same site.  
- See section IV below for more tips.  

### Online trainings (completely distributed)  
- When watching videos, have all participants watch separately.  
- Assign breakout groups randomly to breakout rooms in Zoom. Be sure to remove Trainers and helpers when assigning groups.
- Use the [virtual minute card][minute-cards-template] form to get feedback at lunch breaks and end of each day.  
- Have participants screen share with their breakout room during the live coding exercises.   
- For exercise to set up a workshop website, put participants in breakout rooms and have one person screen share while the others help guide them verbally.
- See section IV below for more tips.  

## IV. Using Zoom  for Online Trainings

<a name="zoom"></a>

Online Carpentry Instructor Training events are held on [Zoom][zoom-home]. You can set up a personal Zoom
account for yourself for free. This personal account will be able to attend the training event
(or any other online Carpentry event), but will not be able to act as host.   

### Becoming the meeting host

About a week before your event, you will be given login credentials for a Carpentry account. Alternatively, if no
one has yet claimed "host" in your session, you can click "claim host" next to your name in the Participants list;
you will be asked for a 6-digit host key, which you can find [in this message](https://carpentries.topicbox.com/groups/trainers/T3ec157cc9a3d1833/zoom-host-code).
See [the explanation here][zoom-host-key] for step-by-step instructions on how to
claim host in Zoom Rooms using the host key.

This account will be the host for the event and will have extra privileges including the
ability to mute participants and assign participants into breakout rooms. Decide ahead of time with your co-Trainer(s) who will log-in with/claim these credentials. The host
can transfer host privileges to other participants, so you will be able to trade host status
back and forth with your co-Trainers during the event.  

All Carpentry online events are set-up such that participants can enter the room without the
host being present. If you ever get an error message saying you can’t join the room because
you’re not the host, please contact Carpentry staff immediately.   

### Host abilities:  
- “Mute” is in the lower left. To mute other participants, the host can go to “Manage Participants”, hover over a participant’s name, and click “mute”.  
- When the room host clicks “End Meeting”, a dialogue box appears with three options: “Cancel”, “Leave Meeting” and “End Meeting for All”. Be careful not to end the meeting if you are simply leaving the room temporarily while your co-Trainer teaches.  
- Only the host has the ability to create “Breakout rooms”. The button for this is on the lower left. Breakout rooms can be assigned automatically. By default, participants will be assigned to the same groups each time breakout rooms are used. You can change participants' assignments manually if desired.  
- The host can move between breakout rooms and can send messages to all rooms simultaneously.  

### General tips for online training:  
- **Support the lead**
	- It is tempting to check-out and check email/do work when your co-teacher has taken the wheel.  Try not to do this!  Ways that you can support your co-teacher when they are leading are:
	  - Monitor the chat in zoom/notes
	  - Help post exercises + provide instructions
	  - Find links or references
	- Make sure that whomever is actively teaching always has host privileges. When you take turns instructing, remember to hand-off host privileges during the change-over.
- **Exercise management**
  - After the first exercise, keep a list of all the participants in a plain text file on your computer so can you can easily paste it into the shared note-taking doc for exercises. This way, everyone immediately has a place to start writing.(G.W.) Tip: randomise the order of names every once in a while so it is not always the same person that is first or last in the list, and thus may get more or less attention when you discuss the responses (LN.)
  - Screen-share a timer/countdown clock (like [this timer from timeanddate.com](https://www.timeanddate.com/timer/)) so participants know how long they have to work on exercises. (L.N) [Cuckoo timers](https://cuckoo.team/carpentries-instructor-training) can also be helpful, especially during breakout room sessions: the countdown timer is shared between everyone visiting the webpage and all participants will hear an alarm sound when the timer runs out.
- **Shared notes tips**
  - No matter what kind of shared doc you are using, it is usually a good idea to create
  two documents -- one for each day of the training.  
    - Suggestion from AN: create a third doc for sharing concept maps, since they are
    images and can slow down the document.  
  - Etherpad pros + cons
    - Pros: line numbers
    - Cons: simple formatting
  - Google Doc pros + cons
    - Pros: richer formatting
    - Cons: no line numbers
  - Have a plaintext list of names that you can paste into the Etherpad/Google Doc. Reduces confusion when a bunch of people need to answer something at once, and subtly makes it clear that everyone needs to respond.
- **Zoom tips**
  - Announce *at the beginning* of the training that all participants should mute when
  they are not talking.  You may need to repeat this a few times during the early part
  of the training, until people are doing it consistently.  
  - In general, it works best to have everyone use zoom individually on their computers
  (so you can see everyone's faces); for trainings where some of the participants are
  co-located, have them use their own computer for video but pick one person to use
  for mic/sound.  
  - “Gallery view” in the upper right toggles the display to show more participants' videos.  
  - “Share screen” is at the bottom middle of the screen. To end “share screen”, click the red button that will appear at the top middle of the screen when you are in screen sharing mode.  
  - When you screen share, you have the option to share individual apps or your entire desktop. The default is the full desktop.
  - The Zoom chat is not stable (it is not saved across sessions or after going into breakout rooms, and people who have just joined a room cannot see previously posted chat items). We highly recommend using the Etherpad or Google Doc chat instead. For those who want to save the chat, they do that using the "More" option in the chat window, which offers "Save chat". Choosing this will save the chat to a local text file on the person's computer.
  - During breaks, learners will often turn off their video and wait for your audio cue to re-activate. This makes it look like no one is back from break, but just saying 'hello' will generally get a bunch of people to come back on video quickly.
  - When several attendees are in the same room (member trainings): it is helpful to have every participant log in separately so that you can see names and faces and they can interact by waving or using the chat. However, it is important that only one microphone and speaker should be active in the room at one time or feedback and noise will be a problem. When creating breakouts, you can either leave these people in the main room or shuffle people around to create a room just for them. Either way, ask them to leave a mic on so you can listen in.
  - Attendees might like to have a separate room (without Trainers) to network in over lunch or other breaks. Be prepared to assign that room and then close it to restart the main session.
  - You can never practice too much with Zoom!

## V. Curriculum Teaching Tips

<a name="curriculum"></a>

This is a place for Trainers to leave tips and observations for those newer to the curriculum. This can provide guidance on how to navigate difficult places in the curriculum until problems can be fixed, or may provide additional instructions that are conditional to an audience or are otherwise not appropriate to/ready for a change in the curriculum itself.

### Breaks

* Giving breaks is *extremely* important -- for learners to decompress, take a walk, check email, etc.  Make sure to give
learners a full 60 minutes for lunch and 15-20 minutes for the morning/afternoon break. (EW)
- Make good use of breaks - use them for a short exercise, or just give a break entirely for people to take a breather.

### Welcome

* From JS: "What happens is that we send participants home at the end of day one with a request to look up more about the Carpentries workshop types and then we ask them what questions they have at the start of day two. While the intent is that these questions will be put in the Etherpad and then taken up later in one way or another this does not happen or at least only happens in part. The result is either a lot of saying, "We will cover that this afternoon" or pulling parts of the relevant afternoon sessions into the morning. Participants thus either end up a little frustrated (because they would really like an answer now) or the schedule ends up being a little fractured."
	* Response from CK: I have never had the problem described by JS; people are usually willing to wait (especially once we dive into live coding), and I make sure to answer all questions (and take new ones!) in the afternoon.
	* Response from KW: Another option is to have people put questions into the Etherpad in the morning, and then answer them (in the Etherpad) during the live coding practice. Trainees can read them at any time then, and you can refer back to them when necessary.

### Building Skill with Practice
People often request to see more examples of concept maps. These are some examples linked from a previous version of the curriculum:

* [Array Math](../fig/array-math.png)
* [Conditionals](../fig/conditionals.png)
* [Creating and Destroying Files](../fig/create-destroy.png)
* [Sets and Dictionaries in Python](../fig/dict-set.png)
* [Input and Output](../fig/io.png)
* [Lists and Loops](../fig/lists-loops.png)
* [Git Version Control](../fig/git_concept_map.png)

Most of these are much larger than our recommended limit for the activity. It can be helpful to make a larger map and then narrow down to a smaller one.

### Expertise and Instruction
### Memory and Cognitive Load
### Building Skill with Feedback
### Motivation and Demotivation

As written, this can run long.  Suggestions:

* CK: In general, I approach this section as "which 3 out of the N exercises do I want to make SURE I do?" and then if there is time (or interest! depends on the group) I will add or adapt.

### Mindset
### Teaching is a Skill
### Wrap-Up and Homework

### Welcome Back
### Live Coding	is a Skill
### Lesson Study
### More Practice Live Coding
### Managing a Diverse Classroom

### The Carpentries: How We Operate

* CK: Not an "official" exercise, but after explaining the workshops and how to run them,
go around the room, asking each person if they have a question + then answer them.  

* Exercise: Creating a Workshop Website
   * CK: This takes some time, so some people opt to skip this section.  Inevitably,
   when working with a group of mixed experience with GitHub, some will be able
   to zip through this exercise, where others will struggle.  We **have** gotten
   positive feedback about this exercise as well, where learners felt like it was
   a valuable experience. Can be especially valuable for groups that will probably
   be running workshops on their own (so open trainings, or trainings for folks
   who are ready to get started right away).  

* CK: The coffee break after this would be a great time for an "Ask and Offer" if the
group is interested.

### Workshop Introductions

* More or less time
    * CK: The second major exercise (writing a mini-introduction and then
    practicing) can be made longer if you have the time or people are
    very keen on practicing their introductions.  Instead of 2 minutes,
    people could talk for 4-5 minutes each.  

### Afternoon Wrap-Up

## VI. Teaching Demonstration Tips

This section contains tips and tricks on demo hosting that may be contributed by any Trainer describing things that work for them. For official/technical guidelines on how to run a demo, see the [Handbook](https://docs.carpentries.org/topic_folders/instructor_training/trainers_guide.html#running-a-teaching-demonstration).

Suggested points to make during introductions:
* This is not a high-stakes test! This is a friendly opportunity to give and receive feedback. On occasion, we do invite
people to return for a second try. If we do this, your follow-up email will contain very clear instructions on exactly what
we would like you to change on your next visit. This does not mean we do not want you as an instructor, it means we want you to be
ready to put your best foot forward in the classroom and we are here to help you do that. (KW)
* I will not tell anyone that they have passed or ask anyone to repeat during this session. That information will come in the follow up email. (KW)
* The feedback you give sometimes says as much or more about your approach to instruction as the demo itself. (KW)
* Have trainees introduce themselves (name and institution or location) at the start. This makes sure everyone knows where the
mute button is. (EB)
* I have already determined a random order for you each to do your demonstration. When it is your turn, I will tell you what
episode you will be teaching from, and
you will have a minute or two to set up your screen. You will screen share (describe where the button is) and will have the
option to share your whole Desktop or just a single application. I recommend sharing only the application you will be teaching
from, that way you can keep your notes up on your screen without us seeing them. It is perfectly fine to teach using your
notes - that is how I always teach. (EB)
* When your time is up, I will stop you and ask you to give feedback on yourself and then ask others to add their feedback. (EB)

Different ways of managing feedback during the demo:
* Create your own Etherpad and populate it with episode links, feedback templates, whatever.
* Use +/- content delivery rubric. (Or use "improvement" in place of "-" as suggested by MC). Keep in mind that some learners
(like some Trainers) do not have the content expertise to be able to fully evaluate that category for all lessons.
* If there is time (4 people or less) you can do feedback entirely verbally, or have them issue verbal feedback after writing
notes in the Etherpad. If you do this, suggest having presenter give their own feedback, then other learners, then Trainer can
summarize/disagree/add/emphasize as needed.
* I take notes on physical paper during each demo with points I think need to be made, then mark things off as others
mention them in their feedback. Usually, the trainees catch most of the things I wanted to mention, and I can choose just
one or two things to comment on. (EB)

Suggested points to make during wrap-up:
* Thank you for your excellent feedback! Instructors like you help to make this community what it is.
* I will follow up with each of you by email within ___ (time period). If you do not hear from me by __ feel free to check in.


[handbook]: https://docs.carpentries.org/topic_folders/instructor_training/index.html#for-trainers
[demos]: https://docs.carpentries.org/topic_folders/instructor_training/trainers_guide.html#running-a-teaching-demonstration
[post-template]: https://docs.carpentries.org/topic_folders/instructor_training/email_templates_trainers.html#email-after-training-event
[etherpad-template]: http://pad.software-carpentry.org/ttt-template
[training-template]: https://github.com/carpentries/training-template
[minute-cards-template]: https://docs.google.com/forms/d/1p7iOV5HNvy4POS4g6eottY8RSfKq4kaoKz1-jIFYTMI/template/preview
[checkout-checklist]: http://www.datacarpentry.org/checkout/
[training-repo]: http://carpentries.github.io/instructor-training/
[zoom-home]: https://www.zoom.us/
[zoom-host-key]: https://support.zoom.us/hc/en-us/articles/115001315866-Host-Key-Control-For-Zoom-Rooms
[slides-folder]: https://drive.google.com/drive/folders/10ncHtw4ZtNZD0ozW0rG5C-Q4yFetRY1t
[great-slide-issue]: https://github.com/carpentries/instructor-training/issues/680
[trainer-pad]: https://pad.carpentries.org/trainers
