---
layout: reference
title: "Key Points and References"
root: .
---

## Books

Susan Ambrose et al: *[How Learning Works: Seven Research-Based Principles for Smart Teaching][worldcat-hlw]*.
:   An excellent overview of what we know about education and why we
    believe it is true, covering everything from cognitive psychology
    to social factors.

Stephen D. Brookfield and Stephen Preskill: *[The Discussion Book][worldcat-discussion]*.
:   Describes fifty different ways to get groups talking productively.

Joshua Foer: *[Moonwalking with Einstein: The Art and Science of Remembering Everything][worldcat-moonwalking]*.
:   Discusses memory techniques within the context of training for the U.S. Memory Championship. Compelling read and
    also very informative.

Elizabeth Green: *[Building a Better Teacher][worldcat-babt]*.
:   A well-written look at why educational reforms in the past 50 years have mostly missed the mark,
    and what we should be doing instead.

Mark Guzdial: *[Learner-Centered Design of Computing Education: Research on Computing for Everyone][worldcat-lcdce]*.
:   A well-researched investigation of what it means to design computing courses for everyone,
    not just people who are going to become professional programmers,
    from one of the leading researchers in CS education.

Doug Lemov: *[Teach Like a Champion 2.0][worldcat-tlac]*.
:   Presents 62 classroom techniques drawn from intensive study of thousands of hours of video of good teachers in action.

Therese Huston: *[Teaching What You Do not Know][worldcat-twydk]*.
:   A pointed, funny, and very useful book that explores exactly what the title suggests.

James Lang: *[Small Teaching][worldcat-small-teaching]*.
:   A short guide to evidence-based teaching practices that can be adopted
    without requiring large up-front investments of time and money.

Jane Margolis and Allan Fisher: *[Unlocking the Clubhouse: Women in Computing][worldcat-clubhouse]*.
:   A groundbreaking report on the gender imbalance in computing,
    and the steps Carnegie-Mellon took to address the problem.

Claude M. Steele: *[Whistling Vivaldi: How Stereotypes Affect Us and What We Can Do][worldcat-vivaldi]*.
:   Explains and explores stereotype threat and strategies for addressing it.

## Papers

Baume: "[Writing and Using Good Learning Outcomes]({{ page.root }}/files/papers/baume-learning-outcomes-2009.pdf)"
:   A useful detailed guide to constructing useful learning outcomes.

Borrego and Henderson: "[Increasing the Use of Evidence-Based Teaching in STEM Higher Education: A Comparison of Eight Change Strategies]({{ page.root }}/files/papers/borrego-henderson-change-strategies-2014.pdf)"
:   Describes eight approaches to effecting change in STEM education
    that form a useful framework for thinking about how Software Carpentry and Data Carpentry can change the world.

Brown and Altadmri: "[Investigating Novice Programming Mistakes: Educator Beliefs vs Student Data]({{ page.root }}/files/papers/brown-educator-vs-learner-beliefs-2014.pdf)"
:   Compares teachers' opinions about common programming errors with data from over 100,000 students,
    and finds only weak consensus amongst teachers and between teachers and data.

Carroll, Smith-Kerker, Ford, and Mazur-Rimetz: "[The Minimal Manual](https://doi.org/10.1207/s15327051hci0302_2)" *Human–Computer Interaction*, 3:2, 123-153, 1987.
:   Outlines an approach to documentation and instruction
    in which each lesson is one page long and describes how to accomplish one concrete task.
    Its focus on immediate application,
    error recognition and recovery,
    and reference use after training
    makes it an interesting model for Software and Data Carpentry.

Crouch and Mazur: "[Peer Instruction: Ten Years of Experience and Results]({{ page.root }}/files/papers/crouch-mazur-peer-instruction-ten-years-2001.pdf)"
:   An early report on peer instruction and its effects in the classroom.

Deans for Impact: "[The Science of Learning]({{ page.root }}/files/papers/science-of-learning-2015.pdf)"
:   Summarizes cognitive science research related to how students learn,
    and connects it to practical implications for teaching and learning.

Guzdial: "[Exploring Hypotheses about Media Computation]({{ page.root }}/files/papers/guzdial-mediacomp-retrospective-2013.pdf)"
:   A look back on 10 years of media computation research.

De Bruyckere et al: "[Urban Myths About Learning and Education]({{ page.root }}/files/papers/de-bruyckere-urban-myths-2015.pdf)"
:   A one-page summary drawn from their book of the same name.

Gormally et al: "[Feedback about Teaching in Higher Ed: Neglected Opportunities to Promote Change]({{ page.root }}/files/papers/gormally-teaching-feedback-2014.pdf)"
:   Summarizes best practices for providing instructional feedback and recommends specific strategies for sharing instructional expertise.

Guzdial: "[Why Programming is Hard to Teach]({{ page.root }}/files/papers/guzdial-why-hard-to-teach-2011.pdf)"
:   A chapter from
    *[Making Software][worldcat-making-software]*
    that explores why programming seems so much harder to teach than
    some other standard subjects.

Kirschner et al: "[Why Minimal Guidance During Instruction Does Not Work: An Analysis of the Failure of Constructivist, Discovery, Problem-Based, Experiential, and Inquiry-Based Teaching]({{ page.root }}/files/papers/kirschner-minimal-guidance-fails-2006.pdf)"
:   Argues that inquiry-based learning is less effective for novices than guided instruction.

Lee: "[What can I do today to create a more inclusive community in CS?]({{ page.root }}/files/papers/lee-create-inclusive-community-2015.pdf)".
:   A brief, practical guide on exactly that with references to the research literature.

Mayer and Moreno: "[Nine Ways to Reduce Cognitive Load in Multimedia Learning]({{ page.root }}/files/papers/mayer-reduce-cognitive-load-2003.pdf)"
:   Shows how research into how we absorb and process information
    can be applied to the design of instructional materials.

Porter et al: "[Success in Introductory Programming: What Works?]({{ page.root }}/files/papers/porter-what-works-2013.pdf)"
:   Summarizes the evidence that three techniques---peer instruction, media computation, and pair programming---can
    significantly improve outcomes in introductory programming courses.

Wiggins and McTighe: "[UbD in a Nutshell]({{ page.root }}/files/papers/wiggins-mctighe-ubd-nutshell.pdf)"
:   A four-page summary of the authors' take on reverse instructional design.

Wilson et al: "[Good Enough Practices in Scientific Computing](https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1005510)".
:   Describes and justifies a minimal set of computing practices that every researcher could and should adopt.

Wilson et al: "[Best Practices for Scientific Computing](http://journals.plos.org/plosbiology/article?id=10.1371/journal.pbio.1001745)"
:   Describes and justifies the practices that mature scientific software developers ought to use.

Wilson: "[Software Carpentry: Lessons Learned][swc-lessons-learned]"
:   Summarizes what we have learned in 17 years of running classes for scientists.

[worldcat-babt]: https://www.worldcat.org/title/building-a-better-teacher-how-teaching-works-and-how-to-teach-it-to-everyone/oclc/953075081
[worldcat-clubhouse]: https://www.worldcat.org/title/unlocking-the-clubhouse-women-in-computing/oclc/752326915
[worldcat-discussion]: https://www.worldcat.org/title/discussion-book-50-great-ways-to-get-people-talking/oclc/914221868
[worldcat-moonwalking]: https://www.worldcat.org/title/moonwalking-with-einstein-the-art-and-science-of-remembering-everything/oclc/1023353802
[worldcat-hlw]: https://www.worldcat.org/title/how-learning-works-seven-research-based-principles-for-smart-teaching/oclc/762968489
[worldcat-lcdce]: https://www.worldcat.org/title/learner-centered-design-of-computing-education-research-on-computing-for-everyone/oclc/1028934710&referer=brief_results
[worldcat-making-software]: https://www.worldcat.org/title/making-software-what-really-works-and-why-we-believe-it/oclc/795921229
[worldcat-small-teaching]: https://www.worldcat.org/title/small-teaching-everyday-lessons-from-the-science-of-learning/oclc/968245403
[worldcat-tlac]: https://www.worldcat.org/title/teach-like-a-champion-20-62-techniques-that-put-students-on-thepath-to-college/oclc/946587371
[worldcat-twydk]: https://www.worldcat.org/title/teaching-what-you-dont-know/oclc/806492013
[worldcat-vivaldi]: https://www.worldcat.org/title/whistling-vivaldi-and-other-clues-to-how-stereotypes-affect-us/oclc/987873095
[discovering-speech]: https://books.google.com/books?id=IoTdAUdNkgIC&pg=PA302#v=onepage&q&f=false/
[swc-lessons-learned]: https://f1000research.com/articles/3-62/v2
